package assign;

import parallel.MovableTask;
import util.Util;

//--------fix a position and do a SearchByFixedPosTask on the resulting subsystem--------
// This is split into a separate task from SearchByFixedPosTask because it is where the
// parallelism really begins; each of the subsolutions can be evaluated entirely
// independently.
public class FixPositionTask extends MovableTask {
	private Solution.Reference parentSolutionRef;
	private String s;
	private int pos;
	private int[] ids;
	private int i;
	
	public FixPositionTask(Solution.Reference parentSolutionRef, String s, int pos, int[] ids, int i) {
		this.parentSolutionRef = parentSolutionRef;
		this.s = s;
		this.pos = pos;
		this.ids = ids;
		this.i = i;
	}
	
	protected void runImpl() {
		try {
			Solution parentSolution = parentSolutionRef.get();
			Solution subsolution = new Solution(parentSolution, ids[i], pos);
			int parentSolutionWindowCount = parentSolution.getWindows().length;
			
			// help gc; these objects are no longer needed
			parentSolution = null;
			parentSolutionRef = null;
			
			subsolution.filter();
			
			String updatedS = s + Worker.protein.getSpinSystems()[ids[i]].getReferenceId() + "-" + pos + " " + i + "/" + ids.length + ";  ";
			Util.pln("\nFix " + subsolution.getFixedPos().cardinality() + " positions.");
			Util.pln(updatedS + "\n\n" + subsolution.toStringByWindows());
			
			subsolution.checkAndMergeWindows();
			
			if (subsolution.getWindows().length != parentSolutionWindowCount)
				Util.pln("\n\nMerged windows:\n" + subsolution.toStringByWindows());
			else
				Util.pln("\n\nNo merge.\n");
			
			SearchByFixedPosTask subtask =
				new SearchByFixedPosTask(new Solution.Reference(subsolution), updatedS);
			
			// help gc; this object is no longer needed	
			subsolution = null;
			
			subtask.fork();
			subtask.join();
		}
		catch (Solution.DeadEnd e) {
			Util.pln("Dead End");
		}
		finally {
			// help gc, just in case the reference wasn't cleared already
			parentSolutionRef = null;
		}
	}

	public MovableTask createRemoteEquivalent() {
		return new FixPositionTask.Moved(this);
	}
	
	public void cancel() {
		parentSolutionRef = null;
		super.cancel();
	}

	private static class Moved extends MovableTask {
		private Solution.Reconstructor reconstructor;
		private String s;
		private int pos;
		private int[] ids;
		private int i;

		public Moved(FixPositionTask task) {
			reconstructor = task.parentSolutionRef.reconstructor();
			s = task.s;
			pos = task.pos;
			ids = task.ids;
			i = task.i;
		}

		// copy constructor
		private Moved(FixPositionTask.Moved task) {
			reconstructor = task.reconstructor;
			s = task.s;
			pos = task.pos;
			ids = task.ids;
			i = task.i;
		}

		protected void runImpl() {
			try {
				FixPositionTask task =
					new FixPositionTask(new Solution.Reference(reconstructor), s, pos, ids, i);
				task.fork();
				task.join();
			}
			catch (Solution.DeadEnd e) {
				Util.pln("Ruled out all mappings from that solution");
			}
		}

		public MovableTask createRemoteEquivalent() {
			return new FixPositionTask.Moved(this);
		}
	}
}