package assign;

import parallel.MovableTask;
import util.Util;

//------------search of solutions by fixing one position at a time-----------------------------
public class SearchByFixedPosTask extends MovableTask {
	private Solution.Reference parentSolutionRef;
	private String s;
	
	public SearchByFixedPosTask() {
		this(new Solution.Reference(Solution.getRootSolution()), "Fix ");
	}
	
	public SearchByFixedPosTask(Solution.Reference parentSolutionRef, String s) {
		this.parentSolutionRef = parentSolutionRef;
		this.s = s;
	}
	
	protected void runImpl() {
		
		try {
			Solution parentSolution = parentSolutionRef.get();
			
			//base case: all windows with one strand
			boolean hasOneStrand = true;
			for (int i = 0; i < parentSolution.getWindows().length; i++) {
				if (parentSolution.getWindows()[i].getStrands().length != 1) {
					hasOneStrand = false;
					break;
				}
			}
	
			if (hasOneStrand)
				parentSolution.mergeWindows();
	
			//base case: window of size 1
			if (parentSolution.getWindows().length == 1) {
				Worker.mappingsFound.addStrands(parentSolution.getWindows()[0].getStrands());
				return;
			}
	
			int posToFix = parentSolution.findBestDefinedPosition();
			int[] idToFix = parentSolution.findIdToFix(posToFix);
			MovableTask[] subtasks = new MovableTask[idToFix.length];
	
			//fix candidates with no alternatives
			if (idToFix.length == 1) {
				parentSolution.fixUniqueAlternative(idToFix[0], posToFix);
				parentSolution.filter();

				String updatedS = s + Worker.protein.getSpinSystems()[idToFix[0]].getReferenceId() + "-" + posToFix + " 0/1;  ";
				Util.pln("\nFix " + parentSolution.getFixedPos().cardinality() + " positions.");
				Util.pln(updatedS + "\n\n" + parentSolution.toStringByWindows());
				
				parentSolutionRef.solutionChanged();
				subtasks[0] = new SearchByFixedPosTask(parentSolutionRef, updatedS);
			}
			//fix candidates with several alternatives; the order is reversed so that, when running
			//in a single thread, the tasks will be run sequentially
			else {
				for (int i = 0; i < idToFix.length; i++) {
					subtasks[subtasks.length - i - 1] = new FixPositionTask(parentSolutionRef, s, posToFix, idToFix, i);
				}
			}
			
			// help gc; these objects are no longer needed
			parentSolution = null;
			parentSolutionRef = null;
			
			coInvoke(subtasks);
		}
		catch (Solution.DeadEnd e) {
			Util.pln("Dead End");
		}
		finally {
			// help gc, in case this reference wasn't cleared already
			parentSolutionRef = null;
		}
	}

	public MovableTask createRemoteEquivalent() {
		return new SearchByFixedPosTask.Moved(this);
	}
	
	public void cancel() {
		parentSolutionRef = null;
		super.cancel();
	}

	private static class Moved extends MovableTask {
		private Solution.Reconstructor reconstructor;
		private String s;

		public Moved(SearchByFixedPosTask task) {
			reconstructor = task.parentSolutionRef.reconstructor();
			s = task.s;
		}

		// copy constructor
		private Moved(SearchByFixedPosTask.Moved task) {
			reconstructor = task.reconstructor;
			s = task.s;
		}

		protected void runImpl() {
			try {
				SearchByFixedPosTask task =
					new SearchByFixedPosTask(new Solution.Reference(reconstructor), s);
				task.fork();
				task.join();
			}
			catch (Solution.DeadEnd e) {
				Util.pln("Ruled out all mappings from that solution");
			}
		}

		public MovableTask createRemoteEquivalent() {
			return new SearchByFixedPosTask.Moved(this);
		}
	}
}