package assign;

import input.Protein;
import input.ScoreHandler;
import input.SpinSystem;

import java.io.Serializable;

import output.MappingsFound;
import output.ReferenceMapping;
import util.CommandLine;
import util.Util;

public class Worker {

    public static String dataset;
    public static int maxWindowSize;
    public static int maxMissings;
    public static double deltaScore;

    public static String priorType;

    public static Protein protein;
    public static double alpha;
    public static double beta;

    public static ScoreHandler scoreHandler;
    public static ReferenceMapping referenceMapping;
    public static MappingsFound mappingsFound;

    //-------------------------initialize working environment-----------------------
    public static void initialize(Argument arg) {

        // params for the context
        dataset = arg.dataset;

        // Search space.
        maxMissings = arg.maxMissings;
        priorType = arg.priorType;
        deltaScore = 2 * Math.log(100);

        // Execution parameters.
        maxWindowSize = arg.maxWindowSize;
        SpinSystem.setFlags(arg);

        // Initialaize protein
        protein = new Protein(dataset, arg);
        Util.pln("\n\n" + protein.toStringStats() + "\n\n");

        // Initialize data structures
        alpha = arg.alpha / (protein.getLength() * 3);
        beta = arg.beta / (protein.getLength() * 3 * 2);
        scoreHandler = new ScoreHandler(arg.insureUniqueMatch);
        mappingsFound = new MappingsFound();
        Util.pln(scoreHandler.toStringStats());
    }

    //-----------------------info on reference solution if any----------------------
    public static void computeReferenceSolution() {
        referenceMapping = new ReferenceMapping(protein.getReferenceSequenceById());
        Util.pln(referenceMapping.toString());
    }

    //------------------------------------------------------------------------------
    //-----------------COMMAND LINE ARGUMENTS---------------------------------------
    //------------------------------------------------------------------------------
    public static class Argument extends CommandLine.Optional implements Serializable {
        String usage =
            "----------PARAMETERS WITH NO DEFAULTS:------------\n"
                + "-dataset<s>                              name of the input file in the MBA format\n"
                + "-maxMissings<i>                          max number of missing spin systems\n"
                + "\n"
                + "\n"
                + "----------PARAMETERS WITH DEFAULTS:------------\n"
                + "-minChemicalShiftCount<i>[0]             min number of chemical shifts per spin system (not counting HN and N)\n"
                + "-insureUniqueMatch<b>[false]             if true, skip comparing unique matches with missing spin systems\n"
                + "-alpha<d>[0.0001]                        cut-off for consisent spin systems\n"
                + "-beta<d>[0.0001]                         cut-off for consistend strands\n"
                + "-priorType<s>[malliavin]                 type of prior amino acid characterization.\n"
                +"                                          Malliavin by default, other options are bmrb and refdb\n"
                + "-usec,-useca,-usecb,-useha<b>[true]      true by default. Set to false to ignore a resonance type\n"
                + "                                         (need not to be set to false if no data on a resonance type is collected)\n"
                + "-useh,-usen<b>[false]                    false by defalt. Set to true to use these resonance types for amino acid typing\n"
                + "tauH,-tauN,-tauC,-tauCA,-tauCB,tauHA<d>  experimental variance of the observed resonances\n"
                + "maxWindowSize<i>[300000]                 max number of strands per window";

        public String dataset;
        // Search space.
        public int maxMissings;
        public int minChemicalShiftCount;
        public boolean insureUniqueMatch = false;
        public double alpha = 0.0001;
        public double beta = 0.0001;
        public String priorType = "malliavin";

        // Resonance types to use.
        public boolean usec = true;
        public boolean useca = true;
        public boolean usecb = true;
        public boolean useha = true;
        public boolean useh = false;
        public boolean usen = false;

        // Experimental precision.
        public double tauH = 0.000069444;
        public double tauN = 0.01361111;
        public double tauC = 0.00694;
        public double tauCA = 0.02777778;
        public double tauCB = 0.02777778;
        public double tauHA = 0.0002777778;

        // Max number of strands per window.
        public int maxWindowSize = 300000;

        // Settings to control parallelization.
        public String mode = "local";
        public int threads = 1;
        public int port = 1099;
        public String servers = "";

        public String toString() {
            return usage;
        }

    }

}
