/*
 * Means and covariance matrices from the restricted bmrb
 * Ref: Malliavin
 *  */
package input;

import util.BitSet;
import util.Util;
import Jama.Matrix;

public class Bmrb {

    //------------------------------------------------------------------------------------------
    //--------------------------------AMINO ACID TYPES------------------------------------------
    //------------------------------------------------------------------------------------------
    //----------------------------------amino acid types----------------------------------------
    static public String[] aaNames1 = new String[] { "A", "R", "D", "N", "C", "E", "Q", "G", "H", "I", "L", "K", "M", "F", "P", "S", "T", "W", "Y", "V", "B" };
    static public String[] aaNames3 = new String[] { "Ala", "Arg", "Asp", "Asn", "Cys", "Glu", "Gln", "Gly", "His", "Ile", "Leu", "Lys", "Met", "Phe", "Pro", "Ser", "Thr", "Trp", "Tyr", "Val", "Unk" };

    //--------------------------------------dimensions------------------------------------------
    static private String[] dimAla = new String[] { "H", "HA", "HB", "C", "CA", "CB", "N" };
    static private String[] dimArg = new String[] { "H", "HA", "HB2", "HB3", "HG2", "HG3", "HD2", "HD3", "HE", "HH11", "HH12", "HH21", "HH22", "C", "CA", "CB", "CG", "CD", "CZ", "N", "NE", "NH1", "NH2" };
    static private String[] dimAsp = new String[] { "H", "HA", "HB2", "HB3", "C", "CA", "CB", "CG", "N" };
    static private String[] dimAsn = new String[] { "H", "HA", "HB2", "HB3", "HD21", "HD22", "C", "CA", "CB", "CG", "N", "ND2" };
    static private String[] dimCys = new String[] { "H", "HA", "HB2", "HB3", "HG", "C", "CA", "CB", "N" };
    static private String[] dimGlu = new String[] { "H", "HA", "HB2", "HB3", "HG2", "HG3", "C", "CA", "CB", "CG", "CD", "N" };
    static private String[] dimGln = new String[] { "H", "HA", "HB2", "HB3", "HG2", "HG3", "HE21", "HE22", "C", "CA", "CB", "CG", "CD", "N", "NE2" };
    static private String[] dimGly = new String[] { "H", "HA", "HA2", "C", "CA", "N" };
    static private String[] dimHis = new String[] { "H", "HA", "HB2", "HB3", "HD1", "HD2", "HE1", "HE2", "C", "CA", "CB", "CG", "CD2", "CE1", "N", "ND1", "NE2" };
    static private String[] dimIle = new String[] { "H", "HA", "HB", "HG12", "HG13", "HG2", "HD1", "C", "CA", "CB", "CG1", "CG2", "CD1", "N" };
    static private String[] dimLeu = new String[] { "H", "HA", "HB2", "HB3", "HG", "HD1", "HD2", "C", "CA", "CB", "CG", "CD1", "CD2", "N" };
    static private String[] dimLys = new String[] { "H", "HA", "HB2", "HB3", "HG2", "HG3", "HD2", "HD3", "HE2", "HE3", "HZ", "C", "CA", "CB", "CG", "CD", "CE", "N", "NZ" };
    static private String[] dimMet = new String[] { "H", "HA", "HB2", "HB3", "HG2", "HG3", "HE", "C", "CA", "CB", "CG", "CE", "N" };
    static private String[] dimPhe = new String[] { "H", "HA", "HB2", "HB3", "HD1", "HD2", "HE1", "HE2", "HZ", "C", "CA", "CB", "CG", "CD1", "CD2", "CE1", "CE2", "CZ", "N" };
    static private String[] dimPro = new String[] { "HA", "HB2", "HB3", "HG2", "HG3", "HD2", "HD3", "C", "CA", "CB", "CG", "CD", "N" };
    static private String[] dimSer = new String[] { "H", "HA", "HB2", "HB3", "HG", "C", "CA", "CB", "N" };
    static private String[] dimThr = new String[] { "H", "HA", "HB", "HG1", "HG2", "C", "CA", "CB", "CG2", "N" };
    static private String[] dimTrp = new String[] { "H", "HA", "HB2", "HB3", "HD1", "HE1", "HE3", "HZ2", "HZ3", "HH2", "C", "CA", "CB", "CG", "CD1", "CD2", "CE2", "CE3", "CZ2", "CZ3", "CH2", "N", "NE1" };
    static private String[] dimTyr = new String[] { "H", "HA", "HB2", "HB3", "HD1", "HD2", "HE1", "HE2", "HH", "C", "CA", "CB", "CG", "CD1", "CD2", "CE1", "CE2", "CZ", "N" };
    static private String[] dimVal = new String[] { "H", "HA", "HB", "HG1", "HG2", "C", "CA", "CB", "CG1", "CG2", "N" };
    static private String[] dimUnk = new String[] { "H", "HA", "C", "CA", "CB", "N" };

    public static String[][] dim = new String[][] { dimAla, dimArg, dimAsp, dimAsn, dimCys, dimGlu, dimGln, dimGly, dimHis, dimIle, dimLeu, dimLys, dimMet, dimPhe, dimPro, dimSer, dimThr, dimTrp, dimTyr, dimVal, dimUnk };

    //------------------------------------------------------------------------------------------------
    //-----------------------------------------MEANS--------------------------------------------------
    //------------------------------------------------------------------------------------------------
    //------------------------------------malliavin means---------------------------------------------
    static private Matrix malMeanAla = new Matrix(new double[] { 8.194, 4.2694, 1.3582, 177.7117, 53.1099, 19.0253, 123.2269 }, dimAla.length);
    static private Matrix malMeanArg = new Matrix(new double[] { 8.246, 4.2914, 1.8033, 1.7668, 1.5879, 1.5549, 3.1216, 3.109, 7.3358, 6.7996, 6.7771, 6.7286, 6.7666, 176.5078, 56.8464, 30.6366, 27.3036, 43.1232, 159.1613, 120.714, 90.7652, 72.9152, 75.2665 }, dimArg.length);
    static private Matrix malMeanAsp = new Matrix(new double[] { 8.3192, 4.5997, 2.7407, 2.6693, 176.427, 54.6836, 40.8949, 179.0951, 120.7556 }, dimAsp.length);
    static private Matrix malMeanAsn = new Matrix(new double[] { 8.3745, 4.675, 2.8236, 2.7584, 7.3529, 7.1707, 175.319, 53.4842, 38.6704, 176.4267, 119.1223, 112.6939 }, dimAsn.length);
    static private Matrix malMeanCys = new Matrix(new double[] { 8.4047, 4.6922, 2.9717, 2.9351, 1.9777, 174.9524, 57.7606, 33.8233, 120.1659 }, dimCys.length);
    static private Matrix malMeanGlu = new Matrix(new double[] { 8.3681, 4.26, 2.0325, 2.0079, 2.2944, 2.2687, 176.8991, 57.3652, 29.9897, 35.9824, 182.0436, 120.6137 }, dimGlu.length);
    static private Matrix malMeanGln = new Matrix(new double[] { 8.2306, 4.291, 2.057, 2.0166, 2.324, 2.3115, 7.1979, 7.0618, 176.4376, 56.5968, 29.1875, 33.8189, 179.5307, 119.907, 111.7725 }, dimGln.length);
    static private Matrix malMeanGly = new Matrix(new double[] { 8.3144, 3.9781, 3.8907, 174.0644, 45.3565, 109.6352 }, dimGly.length);
    static private Matrix malMeanHis = new Matrix(new double[] { 8.2582, 4.5987, 3.1314, 3.0623, 8.7188, 6.9379, 7.8215, 9.9298, 175.2926, 56.5356, 30.2568, 132.5345, 119.7836, 136.742, 119.4047, 178.1194, 173.5946 }, dimHis.length);
    static private Matrix malMeanIle = new Matrix(new double[] { 8.2741, 4.194, 1.7913, 1.3073, 1.2136, 0.7894, 0.7018, 175.8349, 61.5753, 38.6809, 27.7243, 17.5928, 13.714, 121.5939 }, dimIle.length);
    static private Matrix malMeanLeu = new Matrix(new double[] { 8.214, 4.3255, 1.6508, 1.5469, 1.5236, 0.7668, 0.7465, 176.9595, 55.599, 42.2581, 26.7022, 24.6443, 24.0965, 121.9072 }, dimLeu.length);
    static private Matrix malMeanLys = new Matrix(new double[] { 8.1902, 4.2699, 1.7852, 1.7506, 1.3762, 1.3497, 1.6574, 1.6038, 2.9295, 2.9217, 7.5173, 176.5782, 56.881, 32.7689, 24.9267, 28.8329, 41.805, 120.9421, 43.1993 }, dimLys.length);
    static private Matrix malMeanMet = new Matrix(new double[] { 8.2328, 4.3983, 2.0351, 2.0107, 2.4339, 2.4004, 1.873, 176.1329, 56.0923, 33.1121, 31.8934, 17.3504, 120.0479 }, dimMet.length);
    static private Matrix malMeanPhe = new Matrix(new double[] { 8.3321, 4.6486, 2.9994, 2.9485, 7.0464, 7.0537, 7.0591, 7.0656, 7.0132, 175.4665, 57.9954, 39.9316, 138.5379, 131.4885, 131.4676, 130.4128, 130.3269, 129.0796, 120.5105 }, dimPhe.length);
    static private Matrix malMeanPro = new Matrix(new double[] { 4.4, 2.07, 2.03, 1.94, 1.92, 3.64, 3.62, 176.78, 63.25, 31.74, 27.2, 50.3, 130.78 }, dimPro.length);
    static private Matrix malMeanSer = new Matrix(new double[] { 8.29, 4.5, 3.88, 3.86, 5.36, 174.62, 58.6, 63.79, 116.25 }, dimSer.length);
    static private Matrix malMeanThr = new Matrix(new double[] { 8.26, 4.47, 4.17, 4.77, 1.15, 174.55, 62.12, 69.59, 21.45, 115.59 }, dimThr.length);
    static private Matrix malMeanTrp = new Matrix(new double[] { 8.31, 4.7, 3.21, 3.17, 7.16, 10.11, 7.24, 7.2, 6.76, 6.9, 176.18, 57.67, 30, 110.21, 126.37, 127.46, 137.67, 120.45, 114.14, 121.37, 123.57, 121.63, 129.5 }, dimTrp.length);
    static private Matrix malMeanTyr = new Matrix(new double[] { 8.35, 4.63, 2.91, 2.88, 6.9, 6.9, 6.68, 6.67, 9.04, 175.41, 58.08, 39.26, 128.67, 132.59, 132.46, 117.79, 117.86, 156.44, 120.8 }, dimTyr.length);
    static private Matrix malMeanVal = new Matrix(new double[] { 8.29, 4.17, 1.99, 0.84, 0.82, 175.74, 62.49, 32.6, 21.43, 21.31, 121.1 }, dimVal.length);
    static private Matrix malMeanUnk = new Matrix(new double[] { 5, 5, 100, 100, 100, 100 }, dimUnk.length);
    
    public static Matrix[] malMean = new Matrix[] { malMeanAla, malMeanArg, malMeanAsp, malMeanAsn, malMeanCys, malMeanGlu, malMeanGln, malMeanGly, malMeanHis, malMeanIle, malMeanLeu, malMeanLys, malMeanMet, malMeanPhe, malMeanPro, malMeanSer, malMeanThr, malMeanTrp, malMeanTyr, malMeanVal, malMeanUnk };

    //-------------------------------------bmrb means---------------------------------------------
    static private Matrix bmrbMeanAla = new Matrix(new double[] { 8.19, 4.26, 1.37, 177.84, 53.17, 18.89, 123.18 }, dimAla.length);
    static private Matrix bmrbMeanArg = new Matrix(new double[] { 8.24, 4.29, 1.8, 1.78, 1.58, 1.57, 3.13, 3.12, 7.34, 6.79, 6.76, 6.78, 6.76, 176.51, 56.84, 30.57, 27.27, 43.13, 159.16, 120.7, 92.62, 73.44, 73.98 }, dimArg.length);
    static private Matrix bmrbMeanAsp = new Matrix(new double[] { 8.33, 4.61, 2.74, 2.69, 176.45, 54.6, 40.79, 179.22, 120.77 }, dimAsp.length);
    static private Matrix bmrbMeanAsn = new Matrix(new double[] { 8.36, 4.68, 2.81, 2.78, 7.32, 7.17, 175.34, 53.49, 38.61, 176.8, 119.08, 112.87 }, dimAsn.length);
    static private Matrix bmrbMeanCys = new Matrix(new double[] { 8.42, 4.71, 2.96, 2.94, 3.32, 174.75, 57.55, 34.13, 119.89 }, dimCys.length);
    static private Matrix bmrbMeanGlu = new Matrix(new double[] { 8.34, 4.25, 2.04, 2.03, 2.3, 2.29, 177.02, 57.44, 29.99, 36.04, 182.38, 120.71 }, dimGlu.length);
    static private Matrix bmrbMeanGln = new Matrix(new double[] { 8.22, 4.28, 2.04, 2.03, 2.32, 2.31, 7.19, 7.05, 176.39, 56.56, 29.14, 33.71, 179.75, 119.87, 111.86 }, dimGln.length);
    static private Matrix bmrbMeanGly = new Matrix(new double[] { 8.33, 3.95, 3.92, 173.97, 45.34, 109.7 }, dimGly.length);
    static private Matrix bmrbMeanHis = new Matrix(new double[] { 8.25, 4.63, 3.1, 3.08, 9.15, 7.07, 8.04, 10.12, 175.24, 56.47, 30.18, 130.85, 119.57, 136.75, 119.41, 193.4, 175.14 }, dimHis.length);
    static private Matrix bmrbMeanIle = new Matrix(new double[] { 8.28, 4.19, 1.8, 1.29, 1.23, 0.8, 0.7, 175.91, 61.58, 38.53, 27.63, 17.49, 13.43, 121.57 }, dimIle.length);
    static private Matrix bmrbMeanLeu = new Matrix(new double[] { 8.22, 4.32, 1.63, 1.56, 1.52, 0.77, 0.75, 176.98, 55.62, 42.23, 26.69, 24.59, 24.11, 121.8 }, dimLeu.length);
    static private Matrix bmrbMeanLys = new Matrix(new double[] { 8.21, 4.27, 1.78, 1.76, 1.38, 1.36, 1.61, 1.6, 2.92, 2.92, 7.51, 176.68, 56.9, 32.72, 24.88, 28.86, 41.82, 121.05, 73.82 }, dimLys.length);
    static private Matrix bmrbMeanMet = new Matrix(new double[] { 8.25, 4.38, 2.04, 2.01, 2.44, 2.41, 1.88, 176.36, 56.22, 32.96, 32.08, 17.24, 120.01 }, dimMet.length);
    static private Matrix bmrbMeanPhe = new Matrix(new double[] { 8.39, 4.61, 3, 2.97, 6.99, 6.98, 7.02, 7.01, 6.96, 175.56, 58.23, 39.88, 137.04, 131.39, 131.4, 130.49, 130.63, 129.09, 120.67 }, dimPhe.length);
    static private Matrix bmrbMeanPro = new Matrix(new double[] { 4.3968, 2.093, 2.0034, 1.9548, 1.9211, 3.6541, 3.6011, 176.7048, 63.2741, 31.8309, 27.164, 50.257, 131.1711 }, dimPro.length);
    static private Matrix bmrbMeanSer = new Matrix(new double[] { 8.2679, 4.5013, 3.8746, 3.8466, 5.5337, 174.6235, 58.6299, 63.8086, 116.1614 }, dimSer.length);
    static private Matrix bmrbMeanThr = new Matrix(new double[] { 8.2432, 4.4761, 4.1629, 4.8792, 1.1484, 174.5491, 62.1207, 69.5832, 21.5071, 115.5305 }, dimThr.length);
    static private Matrix bmrbMeanTrp = new Matrix(new double[] { 8.2999, 4.733, 3.2244, 3.1473, 7.1502, 10.0729, 7.366, 7.297, 6.9006, 6.9868, 176.2158, 57.7335, 29.911, 110.7864, 126.4757, 126.4587, 136.1602, 120.4665, 114.1167, 120.8216, 123.4696, 121.727, 128.9081 }, dimTrp.length);
    static private Matrix bmrbMeanTyr = new Matrix(new double[] { 8.3149, 4.6323, 2.915, 2.855, 6.9393, 6.9363, 6.7188, 6.7165, 9.2689, 175.4491, 58.0655, 39.2919, 128.6176, 132.2411, 132.1788, 117.9382, 118.0229, 154.3759, 120.7748 }, dimTyr.length);
    static private Matrix bmrbMeanVal = new Matrix(new double[] { 8.2762, 4.1864, 1.9955, 0.8508, 0.8222, 175.6898, 62.3866, 32.682, 21.5301, 21.2539, 121.1766 }, dimVal.length);
    //static private Matrix bmrbMeanUnk = new Matrix(new double[] { 5, 5, 100, 100, 100, 100 }, dimUnk.length);
    
    public static Matrix[] bmrbMean = new Matrix[] { bmrbMeanAla, bmrbMeanArg, bmrbMeanAsp, bmrbMeanAsn, bmrbMeanCys, bmrbMeanGlu, bmrbMeanGln, bmrbMeanGly, bmrbMeanHis, bmrbMeanIle, bmrbMeanLeu, bmrbMeanLys, bmrbMeanMet, bmrbMeanPhe, bmrbMeanPro, bmrbMeanSer, bmrbMeanThr, bmrbMeanTrp, bmrbMeanTyr, bmrbMeanVal, malMeanUnk };

    //-------------------------------------refdb means---------------------------------------------
    static private Matrix refdbMeanAla = new Matrix(new double[] { 8.2, 4.29, Double.NaN, 178.16, 53.44, 19.22, 122.83 }, dimAla.length);
    static private Matrix refdbMeanArg = new Matrix(new double[] { 8.26, 4.29, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 176.79, 57.11, 30.83, Double.NaN, Double.NaN, Double.NaN, 120.35, Double.NaN, Double.NaN, Double.NaN }, dimArg.length);
    static private Matrix refdbMeanAsp = new Matrix(new double[] { 8.33, 4.62, Double.NaN, Double.NaN, 176.69, 54.9, 41.03, Double.NaN, 120.22 }, dimAsp.length);
    static private Matrix refdbMeanAsn = new Matrix(new double[] { 8.4, 4.71, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 175.47, 53.69, 38.93, Double.NaN, 118.83, Double.NaN }, dimAsn.length);
    static private Matrix refdbMeanCys = new Matrix(new double[] { 8.49, 4.79, Double.NaN, Double.NaN, Double.NaN, 174.76, 57.7, 34.65, 119.16 }, dimCys.length);
    static private Matrix refdbMeanGlu = new Matrix(new double[] { 8.34, 4.28, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 177.25, 57.66, 30.19, Double.NaN, Double.NaN, 120.23 }, dimGlu.length);
    static private Matrix refdbMeanGln = new Matrix(new double[] { 8.22, 4.3, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 176.58, 56.77, 29.39, Double.NaN, Double.NaN, 119.54, Double.NaN }, dimGln.length);
    static private Matrix refdbMeanGly = new Matrix(new double[] { 8.33, 3.98, 3.98, 173.97, 45.63, Double.NaN }, dimGly.length);
    static private Matrix refdbMeanHis = new Matrix(new double[] { 8.3, 4.64, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 175.34, 56.65, 30.29, Double.NaN, Double.NaN, Double.NaN, 119.09, Double.NaN, Double.NaN }, dimHis.length);
    static private Matrix refdbMeanIle = new Matrix(new double[] { 8.3, 4.23, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 176.05, 61.89, 38.81, Double.NaN, Double.NaN, Double.NaN, 121.37 }, dimIle.length);
    static private Matrix refdbMeanLeu = new Matrix(new double[] { 8.24, 4.37, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 177.26, 55.78, 42.52, Double.NaN, Double.NaN, Double.NaN, 121.55 }, dimLeu.length);
    static private Matrix refdbMeanLys = new Matrix(new double[] { 8.21, 4.29, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 176.85, 57.12, 33.09, Double.NaN, Double.NaN, Double.NaN, 120.52, Double.NaN }, dimLys.length);
    static private Matrix refdbMeanMet = new Matrix(new double[] { 8.27, 4.4, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 176.67, 56.58, 33.25, Double.NaN, Double.NaN, 119.48 }, dimMet.length);
    static private Matrix refdbMeanPhe = new Matrix(new double[] { 8.42, 4.67, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 175.65, 58.43, 40.08, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 120.12 }, dimPhe.length);
    static private Matrix refdbMeanPro = new Matrix(new double[] { 4.4, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 177.01, 63.61, 31.94, Double.NaN, Double.NaN, Double.NaN }, dimPro.length);
    static private Matrix refdbMeanSer = new Matrix(new double[] { 8.29, 4.56, Double.NaN, Double.NaN, Double.NaN, 174.65, 58.74, 64.15, 115.89 }, dimSer.length);
    static private Matrix refdbMeanThr = new Matrix(new double[] { 8.28, 4.53, Double.NaN, Double.NaN, Double.NaN, 174.62, 62.31, 70.07, Double.NaN, 114.94 }, dimThr.length);
    static private Matrix refdbMeanTrp = new Matrix(new double[] { 8.28, 4.79, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 176.6, 58.05, 30.23, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 120.9, Double.NaN }, dimTrp.length);
    static private Matrix refdbMeanTyr = new Matrix(new double[] { 8.37, 4.7, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 175.54, 58.21, 39.71, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 120.36 }, dimTyr.length);
    static private Matrix refdbMeanVal = new Matrix(new double[] { 8.31, 4.2, Double.NaN, Double.NaN, Double.NaN, 175.91, 62.82, 32.87, Double.NaN, Double.NaN, 120.62 }, dimVal.length);
    //static private Matrix refdbMeanUnk = new Matrix(new double[] { 5, 5, 100, 100, 100, 100 }, dimUnk.length);
    
    public static Matrix[] refdbMean = new Matrix[] { refdbMeanAla, refdbMeanArg, refdbMeanAsp, refdbMeanAsn, refdbMeanCys, refdbMeanGlu, refdbMeanGln, refdbMeanGly, refdbMeanHis, refdbMeanIle, refdbMeanLeu, refdbMeanLys, refdbMeanMet, refdbMeanPhe, refdbMeanPro, refdbMeanSer, refdbMeanThr, refdbMeanTrp, refdbMeanTyr, refdbMeanVal, malMeanUnk };




    //------------------------------------------------------------------------------------------------
    //---------------------------------------VARIANCES------------------------------------------------
    //------------------------------------------------------------------------------------------------
    //-----------------------------------malliavin variances------------------------------------------
	static private Matrix malVarAla = new Matrix(new double[][] {
		//H,HA,HB,C,CA,CB,N
		{ 0.388893157,0.066753641,0.010302246,-0.138129771,-0.103758693,0.201784223,0.910506964 },
		{	0.066753641,0.201181904,0.015240384,-0.410387933,-0.545394898,0.518817782,0.354123414 },
		{	0.010302246,0.015240384,0.076845922,0.148634031,0.159432262,-0.03066792,-0.071097814 },
		{	-0.138129771,-0.410387933,0.148634031,10.41564941,2.355870247,-1.571960092,-1.539009452 },
		{	-0.103758693,-0.545394898,0.159432262,2.355870247,4.022233009,-1.555367827,-1.771723867 },
		{	0.201784223,0.518817782,-0.03066792,-1.571960092,-1.555367827,4.426242352,0.985119462 },
		{	0.910506964,0.354123414,-0.071097814,-1.539009452,-1.771723867,0.985119462,17.54739189 }
	});

	static private Matrix malVarArg = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HG2,HG3,HD2,HD3,HE,HH11,HH12,HH21,HH22,C,CA,CB,CG,CD,CZ,N,NE,NH1,NH2
		{ 0.379979909,0.051817566,0.000958621,0.012327435,0.003826897,0.009430617,0.009558307,0.009310055,0.014222514,0.020849505,0.021879235,0.01754947,0.019110261,-0.126444355,-0.05765,0.175971821,0.118065149,-0.01375687,-0.244349822,1.066172004,0.50870347,-0.051735725,0.458440602 },
		{	0.051817566,0.214918256,0.001440523,-0.001226812,0.012165285,0.0084738,0.009135448,0.005618382,0.016726105,0.000140013,-0.000668956,-0.014071219,-0.005295761,-0.389707029,-0.712622643,0.451718301,-0.068087183,-0.001262049,-0.05263776,0.319080055,0.529541194,0.117559843,-0.7924878 },
		{	0.000958621,0.001440523,0.081140414,0.057067953,0.041980177,0.038436018,0.033406444,0.028489599,0.020000504,-0.00534679,-0.003740857,-0.001686329,-0.004859534,0.150960445,0.165514246,-0.069765255,0.037114497,0.023786008,0.059674684,-0.185843945,-0.284457088,-0.133802325,0.270157009 },
		{	0.012327435,-0.001226812,0.057067953,0.089523427,0.038244858,0.045193575,0.030828707,0.039626773,0.019319404,-0.014516214,-0.016633472,-0.00222552,-0.009524342,0.185488984,0.221467808,-0.089470007,0.068574578,0.020054258,0.094535239,-0.153717741,-0.113850504,-0.355702728,0.471149772 },
		{	0.003826897,0.012165285,0.041980177,0.038244858,0.072888032,0.056042854,0.039835174,0.035786264,0.019818299,0.016875813,0.013280939,0.022495661,0.021750487,0.122781508,0.124689207,-0.025540886,0.064726226,0.032310519,0.015641492,-0.091805711,-0.125375003,0.240932435,-1.642984986 },
		{	0.009430617,0.0084738,0.038436018,0.045193575,0.056042854,0.082825147,0.03865562,0.044331558,0.022940394,0.018059189,0.016410871,0.008481729,0.01107843,0.11799103,0.14340727,-0.04882161,0.073529765,0.027995093,0.06491866,-0.081127666,-0.156307235,0.167049721,0.66926837 },
		{	0.009558307,0.009135448,0.033406444,0.030828707,0.039835174,0.03865562,0.080115885,0.065564327,0.053123847,-0.005537785,-0.011958919,0.008952266,-0.001166542,0.061086562,0.059675604,-0.036777243,0.022850126,0.037708476,0.036099996,-0.014247335,0.216743559,-0.296014637,-0.006254569 },
		{	0.009310055,0.005618382,0.028489599,0.039626773,0.035786264,0.044331558,0.065564327,0.082091272,0.04330226,0.015703678,0.011613175,0.020304499,0.020536665,0.072025225,0.087418191,-0.057420138,0.026637178,0.052082118,0.046918664,-0.023806825,0.110268287,0.064397387,-1.132968307 },
		{	0.014222514,0.016726105,0.020000504,0.019319404,0.019818299,0.022940394,0.053123847,0.04330226,0.521420538,-0.025009245,-0.030597115,0.02166334,-0.012888725,-0.105928764,-0.08433573,0.151291505,0.030580152,0.082117692,0.216478109,0.052466869,-0.143638507,-0.697642207,-0.274001658 },
		{	0.020849505,0.000140013,-0.00534679,-0.014516214,0.016875813,0.018059189,-0.005537785,0.015703678,-0.025009245,0.240078732,0.242857829,0.153420851,0.226436287,0.042238608,-0.504824817,0.32984966,-0.355910003,-0.105241314,0,0.125768706,-1.971115232,2.919858694,-0.676888764 },
		{	0.021879235,-0.000668956,-0.003740857,-0.016633472,0.013280939,0.016410871,-0.011958919,0.011613175,-0.030597115,0.242857829,0.244806096,0.150188327,0.224744588,-0.080114104,-0.745274425,1.144865632,-0.410706788,0.184495956,0,0.143786475,-3.575856686,3.028257132,-0.682150304 },
		{	0.01754947,-0.014071219,-0.001686329,-0.00222552,0.022495661,0.008481729,0.008952266,0.020304499,0.02166334,0.153420851,0.150188327,0.160554126,0.178316996,-0.078606196,0.188984141,0.03674103,-0.284289748,0.092434675,0,-0.246194348,-1.367176771,1.047047734,-0.080515936 },
		{	0.019110261,-0.005295761,-0.004859534,-0.009524342,0.021750487,0.01107843,-0.001166542,0.020536665,-0.012888725,0.226436287,0.224744588,0.178316996,0.234199897,-0.090350583,-0.18473354,0.539184451,-0.269837111,0.14623706,0,-0.003499071,-2.773162127,2.620878935,-0.418439329 },
		{	-0.126444355,-0.389707029,0.150960445,0.185488984,0.122781508,0.11799103,0.061086562,0.072025225,-0.105928764,0.042238608,-0.080114104,-0.078606196,-0.090350583,4.177666187,3.248889446,-1.152763248,0.36692366,0.084675223,0.697700143,-1.656728745,-1.450802088,0.230884522,6.362699509 },
		{	-0.05765,-0.712622643,0.165514246,0.221467808,0.124689207,0.14340727,0.059675604,0.087418191,-0.08433573,-0.504824817,-0.745274425,0.188984141,-0.18473354,3.248889446,6.237079144,-1.459036231,1.070277691,0.525550842,0.506015897,-1.816591024,-0.621117353,-2.492296696,9.299624443 },
		{	0.175971821,0.451718301,-0.069765255,-0.089470007,-0.025540886,-0.04882161,-0.036777243,-0.057420138,0.151291505,0.32984966,1.144865632,0.03674103,0.539184451,-1.152763248,-1.459036231,3.521093845,0.212346211,0.416589141,-0.042601351,0.938016355,0.676394403,2.852878332,-1.122067809 },
		{	0.118065149,-0.068087183,0.037114497,0.068574578,0.064726226,0.073529765,0.022850126,0.026637178,0.030580152,-0.355910003,-0.410706788,-0.284289748,-0.269837111,0.36692366,1.070277691,0.212346211,3.723428011,0.489250869,0.311872095,-0.350748599,2.03805089,-1.131906629,-0.553189993 },
		{	-0.01375687,-0.001262049,0.023786008,0.020054258,0.032310519,0.027995093,0.037708476,0.052082118,0.082117692,-0.105241314,0.184495956,0.092434675,0.14623706,0.084675223,0.525550842,0.416589141,0.489250869,1.264561892,0.163033471,-0.280709267,1.592207193,0.323189199,-0.002051254 },
		{	-0.244349822,-0.05263776,0.059674684,0.094535239,0.015641492,0.06491866,0.036099996,0.046918664,0.216478109,0,0,0,0,0.697700143,0.506015897,-0.042601351,0.311872095,0.163033471,0.793557227,-1.356283903,0.160462171,-0.003500313,-0.04239982 },
		{	1.066172004,0.319080055,-0.185843945,-0.153717741,-0.091805711,-0.081127666,-0.014247335,-0.023806825,0.052466869,0.125768706,0.143786475,-0.246194348,-0.003499071,-1.656728745,-1.816591024,0.938016355,-0.350748599,-0.280709267,-1.356283903,17.18375206,3.762029886,-0.513838828,-0.559501708 },
		{	0.50870347,0.529541194,-0.284457088,-0.113850504,-0.125375003,-0.156307235,0.216743559,0.110268287,-0.143638507,-1.971115232,-3.575856686,-1.367176771,-2.773162127,-1.450802088,-0.621117353,0.676394403,2.03805089,1.592207193,0.160462171,3.762029886,191.2032318,-9.767277718,2.35022974 },
		{	-0.051735725,0.117559843,-0.133802325,-0.355702728,0.240932435,0.167049721,-0.296014637,0.064397387,-0.697642207,2.919858694,3.028257132,1.047047734,2.620878935,0.230884522,-2.492296696,2.852878332,-1.131906629,0.323189199,-0.003500313,-0.513838828,-9.767277718,7.900000095,-1.475518107 },
		{	0.458440602,-0.7924878,0.270157009,0.471149772,-1.642984986,0.66926837,-0.006254569,-1.132968307,-0.274001658,-0.676888764,-0.682150304,-0.080515936,-0.418439329,6.362699509,9.299624443,-1.122067809,-0.553189993,-0.002051254,-0.04239982,-0.559501708,2.35022974,-1.475518107,116.4577179 }
 	});

	static private Matrix malVarAsp = new Matrix(new double[][] {
		//H,HA,HB2,HB3,C,CA,CB,CG,N
		{ 0.347514451,0.009918958,0.011685844,0.00977586,0.019775732,0.077173002,-0.06688007,0.025454829,0.862218857 },
		{	0.009918958,0.103872769,0.018663958,0.009422291,-0.135963962,-0.284284771,0.208441883,-0.001664506,0.177029923 },
		{	0.011685844,0.018663958,0.078198828,0.023993485,0.011786553,0.002407215,-0.009253411,0.107153624,-0.050359514 },
		{	0.00977586,0.009422291,0.023993485,0.07743758,0.038460225,0.046944935,-0.044882055,-0.051478948,-0.032066908 },
		{	0.019775732,-0.135963962,0.011786553,0.038460225,3.102408648,1.743408203,-0.372338533,-0.152701736,-0.805108011 },
		{	0.077173002,-0.284284771,0.002407215,0.046944935,1.743408203,4.082903862,-0.541946173,0.246954501,-0.737179697 },
		{	-0.06688007,0.208441883,-0.009253411,-0.044882055,-0.372338533,-0.541946173,5.876079559,0.708511949,0.887095153 },
		{	0.025454829,-0.001664506,0.107153624,-0.051478948,-0.152701736,0.246954501,0.708511949,2.270706415,0.39374435 },
		{	0.862218857,0.177029923,-0.050359514,-0.032066908,-0.805108011,-0.737179697,0.887095153,0.39374435,18.30779648 }
	});

	static private Matrix malVarAsn = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HD21,HD22,C,CA,CB,CG,N,ND2
		{ 0.450923204,0.015392673,0.020287829,0.01774529,0.005217238,0.003334899,0.035737548,0.081147604,-0.077372,0.042460188,1.193587899,-0.156893075 },
		{	0.015392673,0.143643573,0.009927389,0.005660936,0.006789073,0.006418524,-0.165111452,-0.346845806,0.309844106,-0.048919752,0.252007335,0.012389151 },
		{	0.020287829,0.009927389,0.112062357,0.036604416,0.050484002,0.007363749,0.062938124,0.059189841,-0.075909011,0.032276213,-0.079282031,-0.070749261 },
		{	0.01774529,0.005660936,0.036604416,0.109299339,0.011408614,0.043230522,0.074792422,0.111169584,-0.072707571,0.015920484,-0.084229626,-0.017699372 },
		{	0.005217238,0.006789073,0.050484002,0.011408614,0.257179767,-0.054853052,0.00115192,0.037128016,-0.041304998,0.198502407,-0.08484035,0.357497633 },
		{	0.003334899,0.006418524,0.007363749,0.043230522,-0.054853052,0.253361166,0.031232841,0.049651392,0.00972622,-0.026022615,-0.048862524,0.364813387 },
		{	0.035737548,-0.165111452,0.062938124,0.074792422,0.00115192,0.031232841,3.335206032,1.661010027,-0.493608058,-0.660892546,-0.173590928,-0.514589429 },
		{	0.081147604,-0.346845806,0.059189841,0.111169584,0.037128016,0.049651392,1.661010027,3.566640377,-0.285396427,-0.124333404,-1.096744418,0.679273069 },
		{	-0.077372,0.309844106,-0.075909011,-0.072707571,-0.041304998,0.00972622,-0.493608058,-0.285396427,2.772483587,-0.32532683,0.702663243,0.485689312 },
		{	0.042460188,-0.048919752,0.032276213,0.015920484,0.198502407,-0.026022615,-0.660892546,-0.124333404,-0.32532683,17.17627525,-1.309406877,0.661716104 },
		{	1.193587899,0.252007335,-0.079282031,-0.084229626,-0.08484035,-0.048862524,-0.173590928,-1.096744418,0.702663243,-1.309406877,17.92962646,0.61985445 },
		{	-0.156893075,0.012389151,-0.070749261,-0.017699372,0.357497633,0.364813387,-0.514589429,0.679273069,0.485689312,0.661716104,0.61985445,19.49282265 }
	});

	static private Matrix malVarCys = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HG,C,CA,CB,N
		{ 0.485996723,0.080462121,0.004246237,-0.016780363,-0.014921153,-0.144330621,-0.213110566,0.434573323,1.211585283 },
		{	0.080462121,0.333546102,0.126979798,0.113348849,-0.009434484,-0.576139212,-1.163940072,1.590186,-0.053903706 },
		{	0.004246237,0.126979798,0.610078633,0.369536281,-0.00305167,0.040264025,0.006539376,0.672870696,-0.151115254 },
		{	-0.016780363,0.113348849,0.369536281,0.682826817,0.016822012,0.148233414,0.009076054,0.474792212,-0.291136473 },
		{	-0.014921153,-0.009434484,-0.00305167,0.016822012,0.006654344,0,0.07565856,0.015222012,-0.300354809 },
		{	-0.144330621,-0.576139212,0.040264025,0.148233414,0,4.439799309,3.520421028,-3.187528133,0.071404062 },
		{	-0.213110566,-1.163940072,0.006539376,0.009076054,0.07565856,3.520421028,12.10360527,-12.6082077,0.066212125 },
		{	0.434573323,1.590186,0.672870696,0.474792212,0.015222012,-3.187528133,-12.6082077,45.60238266,-1.981469274 },
		{	1.211585283,-0.053903706,-0.151115254,-0.291136473,-0.300354809,0.071404062,0.066212125,-1.981469274,20.41576767 }
	});

	static private Matrix malVarGlu = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HG2,HG3,C,CA,CB,CG,CD,N
		{ 1.065708041,0.028409584,0.002206761,0.008373436,0.006230299,0.007387238,-0.112140514,0.076923966,0.006586985,0.005443899,-0.248474166,0.840083718 },
		{	0.028409584,0.184435129,0.001588819,0.000158923,-0.003926818,-0.004524304,-0.358527064,-0.62476927,0.471290678,-0.016700104,-0.550286233,0.305847883 },
		{	0.002206761,0.001588819,0.053614773,0.035170961,0.02647928,0.022427199,0.101565577,0.109461591,-0.02618487,0.027129212,0.050470106,-0.099745125 },
		{	0.008373436,0.000158923,0.035170961,0.057030134,0.023785438,0.028986948,0.101480976,0.13136515,-0.034423258,0.032988116,0.225959614,-0.074220605 },
		{	0.006230299,-0.003926818,0.02647928,0.023785438,0.049791902,0.038037453,0.108549252,0.119066514,-0.054522321,0.025667623,0.072222568,-0.124507822 },
		{	0.007387238,-0.004524304,0.022427199,0.028986948,0.038037453,0.054786138,0.109169655,0.126473948,-0.054097701,0.021346334,0.087695144,-0.08707916 },
		{	-0.112140514,-0.358527064,0.101565577,0.101480976,0.108549252,0.109169655,3.776587725,2.533161163,-1.332312226,0.351864696,1.480964422,-1.506004453 },
		{	0.076923966,-0.62476927,0.109461591,0.13136515,0.119066514,0.126473948,2.533161163,4.447103024,-1.644090891,0.657714665,2.215839863,-1.45833981 },
		{	0.006586985,0.471290678,-0.02618487,-0.034423258,-0.054522321,-0.054097701,-1.332312226,-1.644090891,3.236092091,0.375369012,-1.014446616,0.908443809 },
		{	0.005443899,-0.016700104,0.027129212,0.032988116,0.025667623,0.021346334,0.351864696,0.657714665,0.375369012,2.206023455,2.189632416,-0.202201992 },
		{	-0.248474166,-0.550286233,0.050470106,0.225959614,0.072222568,0.087695144,1.480964422,2.215839863,-1.014446616,2.189632416,4.528904438,0.050848518 },
		{	0.840083718,0.305847883,-0.099745125,-0.074220605,-0.124507822,-0.08707916,-1.506004453,-1.45833981,0.908443809,-0.202201992,0.050848518,23.61843109 }
	});

	static private Matrix malVarGln = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HG2,HG3,HE21,HE22,C,CA,CB,CG,CD,N,NE2
		{ 0.368584126,0.055863302,-0.001812782,0.000770839,0.001105834,-0.001074365,0.025132069,0.001920117,-0.129195258,-0.066168971,0.093533218,0.040379763,0.063028522,0.993085027,0.017260131 },
		{	0.055863302,0.19768773,-0.000149899,0.000313699,0.006173618,0.005079888,0.024931675,0.000848616,-0.364306837,-0.562370718,0.468110621,-0.017777367,0.025463624,0.343462646,0.023098327 },
		{	-0.001812782,-0.000149899,0.086818561,0.056104787,0.043496929,0.036574181,0.027571511,0.006559907,0.107242234,0.161624655,-0.023033479,0.044952232,-0.025828024,-0.19031845,0.027203318 },
		{	0.000770839,0.000313699,0.056104787,0.092359245,0.039452348,0.04730482,0.006320799,0.033439431,0.108070672,0.170721039,-0.050566431,0.045227174,-0.018491957,-0.160538256,0.013587028 },
		{	0.001105834,0.006173618,0.043496929,0.039452348,0.08339645,0.066120125,0.039669942,0.018093286,0.116872788,0.14886561,-0.046881836,0.068726927,-0.036759123,-0.139596269,0.030257519 },
		{	-0.001074365,0.005079888,0.036574181,0.04730482,0.066120125,0.092431828,0.024415772,0.03541296,0.139095157,0.164560542,-0.037570395,0.06994658,-0.000327453,-0.159037307,0.022331867 },
		{	0.025132069,0.024931675,0.027571511,0.006320799,0.039669942,0.024415772,0.21509634,-0.057956159,-0.06498456,-0.039540682,0.035743546,0.031334907,0.154282674,0.082966216,0.319128931 },
		{	0.001920117,0.000848616,0.006559907,0.033439431,0.018093286,0.03541296,-0.057956159,0.224030569,-0.023538815,0.044894002,0.004211839,0.050235365,-0.090171084,-0.039824188,0.309993506 },
		{	-0.129195258,-0.364306837,0.107242234,0.108070672,0.116872788,0.139095157,-0.06498456,-0.023538815,3.704949617,2.760192156,-1.360268235,0.122351341,0.527840078,-1.290239453,-0.571699858 },
		{	-0.066168971,-0.562370718,0.161624655,0.170721039,0.14886561,0.164560542,-0.039540682,0.044894002,2.760192156,5.821583271,-1.694233298,0.517704666,-0.602347493,-1.57735455,-0.629381061 },
		{	0.093533218,0.468110621,-0.023033479,-0.050566431,-0.046881836,-0.037570395,0.035743546,0.004211839,-1.360268235,-1.694233298,3.739701033,0.264872015,0.111244105,0.95373112,0.165592164 },
		{	0.040379763,-0.017777367,0.044952232,0.045227174,0.068726927,0.06994658,0.031334907,0.050235365,0.122351341,0.517704666,0.264872015,7.391874313,0.116118826,-0.412349343,0.232089549 },
		{	0.063028522,0.025463624,-0.025828024,-0.018491957,-0.036759123,-0.000327453,0.154282674,-0.090171084,0.527840078,-0.602347493,0.111244105,0.116118826,2.700308085,0.593761683,0.582103312 },
		{	0.993085027,0.343462646,-0.19031845,-0.160538256,-0.139596269,-0.159037307,0.082966216,-0.039824188,-1.290239453,-1.57735455,0.95373112,-0.412349343,0.593761683,14.2077055,0.129646301 },
		{	0.017260131,0.023098327,0.027203318,0.013587028,0.030257519,0.022331867,0.319128931,0.309993506,-0.571699858,-0.629381061,0.165592164,0.232089549,0.582103312,0.129646301,10.8489399 }
	});

	static private Matrix malVarGly = new Matrix(new double[][] {
		//H,HA,HA2,C,CA,N
		{ 0.476614893,0.031159639,0.040471006,0.089514405,0.063403405,1.046840668 },
		{	0.031159639,0.166928515,0.000991856,-0.056205414,-0.05082513,0.068168528 },
		{	0.040471006,0.000991856,0.179835036,0.030719781,0.031373944,0.130095691 },
		{	0.089514405,-0.056205414,0.030719781,3.643553257,0.931718171,-0.455880135 },
		{	0.063403405,-0.05082513,0.031373944,0.931718171,1.731123567,0.005346781 },
		{	1.046840668,0.068168528,0.130095691,-0.455880135,0.005346781,17.74514389 }
	});

	static private Matrix malVarHis = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HD1,HD2,HE1,HE2,C,CA,CB,CG,CD2,CE1,N,ND1,NE2
		{ 0.560518622,0.183814809,0.228441402,0.171102226,1.021531344,0.293755025,0.348634094,-0.183493435,-0.110542052,-0.058894478,0.061059579,1.071029782,-0.204658896,0.244749188,1.235189915,3.099734783,3.011609078 },
		{	0.183814809,0.38754645,0.301816404,0.216300234,1.255033851,0.26925993,0.330682457,-0.150097549,-0.2557652,-0.538579464,0.399473369,-1.549946189,-0.393185347,0.219108984,0.223175168,5.704565525,3.510776997 },
		{	0.228441402,0.301816404,0.719412923,0.461874396,3.026674271,0.3380211,0.369158655,-0.277232856,0.136567712,0.473954409,-0.210543439,-0.164266944,-0.068276458,0.134873375,0.003221622,-2.493439913,5.621762753 },
		{	0.171102226,0.216300234,0.461874396,0.419169724,2.223877668,0.341952294,0.382903069,-0.143724993,0.157058999,0.471633047,-0.226402089,-1.300931215,-0.17344664,0.1433236,-0.070541114,-0.752676606,2.118610144 },
		{	1.021531344,1.255033851,3.026674271,2.223877668,7.380751133,0.950828552,0.20852387,4.075683594,-1.241470337,4.725707531,-1.99736774,0,8.407128334,2.81966424,-1.715700507,0.293700695,17.25972366 },
		{	0.293755025,0.26925993,0.3380211,0.341952294,0.950828552,1.169705033,1.122253656,0.096209772,0.152888402,0.113683991,-0.039161034,0.348412544,-0.38318038,0.476072609,0.235061646,20.60833359,-3.650742292 },
		{	0.348634094,0.330682457,0.369158655,0.382903069,0.20852387,1.122253656,1.459575415,0.291646123,-0.024624916,-0.021811064,-0.197268173,-3.028702498,-0.736699522,0.344595939,0.046519838,34.47285843,-0.764078915 },
		{	-0.183493435,-0.150097549,-0.277232856,-0.143724993,4.075683594,0.096209772,0.291646123,6.446722031,-1.853567004,-1.56320262,1.58668375,0,-0.14166151,-0.247185916,-5.698187828,85.97528076,-31.47099876 },
		{	-0.110542052,-0.2557652,0.136567712,0.157058999,-1.241470337,0.152888402,-0.024624916,-1.853567004,4.330826283,3.07640481,-0.215609223,3.463238955,0.183384985,0.814362228,0.380845487,2.967477083,7.6914711 },
		{	-0.058894478,-0.538579464,0.473954409,0.471633047,4.725707531,0.113683991,-0.021811064,-1.56320262,3.07640481,6.517858982,-0.58682102,8.312403679,0.67960012,0.782496035,-0.75383234,-50.17486191,6.706722736 },
		{	0.061059579,0.399473369,-0.210543439,-0.226402089,-1.99736774,-0.039161034,-0.197268173,1.58668375,-0.215609223,-0.58682102,4.777988911,6.017297268,-1.885950208,1.6885463,2.014951944,15.08877087,-8.211297035 },
		{	1.071029782,-1.549946189,-0.164266944,-1.300931215,0,0.348412544,-3.028702498,0,3.463238955,8.312403679,6.017297268,9.820725441,-0.913077891,3.485716581,10.72814178,24.10454178,-6.588027 },
		{	-0.204658896,-0.393185347,-0.068276458,-0.17344664,8.407128334,-0.38318038,-0.736699522,-0.14166151,0.183384985,0.67960012,-1.885950208,-0.913077891,11.51477242,-1.225262642,-1.83494091,-66.7223587,48.81427383 },
		{	0.244749188,0.219108984,0.134873375,0.1433236,2.81966424,0.476072609,0.344595939,-0.247185916,0.814362228,0.782496035,1.6885463,3.485716581,-1.225262642,6.151823998,1.146819949,8.312621117,1.881917715 },
		{	1.235189915,0.223175168,0.003221622,-0.070541114,-1.715700507,0.235061646,0.046519838,-5.698187828,0.380845487,-0.75383234,2.014951944,10.72814178,-1.83494091,1.146819949,17.87412643,5.397219181,7.462571621 },
		{	3.099734783,5.704565525,-2.493439913,-0.752676606,0.293700695,20.60833359,34.47285843,85.97528076,2.967477083,-50.17486191,15.08877087,24.10454178,-66.7223587,8.312621117,5.397219181,1288.212891,71.61542511 },
		{	3.011609078,3.510776997,5.621762753,2.118610144,17.25972366,-3.650742292,-0.764078915,-31.47099876,7.6914711,6.706722736,-8.211297035,-6.588027,48.81427383,1.881917715,7.462571621,71.61542511,925.5718994 }
	});

	static private Matrix malVarIle = new Matrix(new double[][] {
		//H,HA,HB,HG12,HG13,HG2,HD1,C,CA,CB,CG1,CG2,CD1,N
		{ 0.484548509,0.127270296,0.005570898,0.017388731,0.001924306,0.007919082,0.007094514,-0.220632389,-0.331657857,0.363998234,0.099463232,-0.002571468,0.111518599,1.548962116 },
		{	0.127270296,0.327042133,-0.008132693,0.00073034,0.00599015,0.013268435,0.009878452,-0.589402795,-1.154142857,0.637375414,-0.286921293,0.042633802,0.03245496,0.254771411 },
		{	0.005570898,-0.008132693,0.093615174,0.05237738,0.047427479,0.045170773,0.04412885,0.128242433,0.144444302,-0.15630807,0.037618343,0.043982197,-0.092296638,-0.154917836 },
		{	0.017388731,0.00073034,0.05237738,0.179707617,0.027600518,0.041362137,0.05371077,0.098250136,0.138551906,-0.051598966,0.154917494,0.0030659,-0.002406804,-0.009465648 },
		{	0.001924306,0.00599015,0.047427479,0.027600518,0.16397652,0.04671073,0.053208165,0.061237413,0.078637436,-0.043060966,0.080541104,0.052237142,-0.028105453,0.02001127 },
		{	0.007919082,0.013268435,0.045170773,0.041362137,0.04671073,0.079187736,0.047898028,0.070435248,0.065912776,0.011957497,0.066349015,0.040473923,-0.033101942,-0.046897564 },
		{	0.007094514,0.009878452,0.04412885,0.05371077,0.053208165,0.047898028,0.130686417,0.046235025,0.077127151,0.029233135,0.101971552,0.033564031,0.055895608,-0.004172215 },
		{	-0.220632389,-0.589402795,0.128242433,0.098250136,0.061237413,0.070435248,0.046235025,3.710621357,3.244227409,-1.472673178,1.186219811,0.461382359,0.392790824,-1.339672923 },
		{	-0.331657857,-1.154142857,0.144444302,0.138551906,0.078637436,0.065912776,0.077127151,3.244227409,7.502469063,-1.826658011,2.392494917,0.335178286,1.294619083,-1.802263022 },
		{	0.363998234,0.637375414,-0.15630807,-0.051598966,-0.043060966,0.011957497,0.029233135,-1.472673178,-1.826658011,4.308437347,0.028018797,0.44331196,1.699410081,0.16695562 },
		{	0.099463232,-0.286921293,0.037618343,0.154917494,0.080541104,0.066349015,0.101971552,1.186219811,2.392494917,0.028018797,16.46050262,0.301725,0.661206663,0.427210987 },
		{	-0.002571468,0.042633802,0.043982197,0.0030659,0.052237142,0.040473923,0.033564031,0.461382359,0.335178286,0.44331196,0.301725,4.408631802,3.078730583,-0.73594439 },
		{	0.111518599,0.03245496,-0.092296638,-0.002406804,-0.028105453,-0.033101942,0.055895608,0.392790824,1.294619083,1.699410081,0.661206663,3.078730583,10.88808823,-0.374605894 },
		{	1.548962116,0.254771411,-0.154917836,-0.009465648,0.02001127,-0.046897564,-0.004172215,-1.339672923,-1.802263022,0.16695562,0.427210987,-0.73594439,-0.374605894,20.16040993 }
	});

	static private Matrix malVarLeu = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HG,HD1,HD2,C,CA,CB,CG,CD1,CD2,N
		{ 0.45207876,0.100313984,0.017883798,0.012751126,0.011032813,0.011017458,0.009247968,-0.187006608,-0.17667307,0.269041568,0.101834238,0.058505852,0.157362923,1.375810146 },
		{	0.100313984,0.228157952,0.003678693,0.001059857,0.005755223,0.015079363,0.015744939,-0.454466075,-0.715846479,0.550790012,0.087588303,0.062419761,0.15511997,0.723896861 },
		{	0.017883798,0.003678693,0.130525515,0.048293229,0.047780279,0.044392262,0.043201398,0.125484362,0.156280622,-0.051658023,0.046725027,0.051981378,0.00533441,-0.060698327 },
		{	0.012751126,0.001059857,0.048293229,0.139994428,0.046007354,0.044291291,0.054013912,0.116722301,0.180219084,-0.034467172,0.057423726,0.003471095,0.060668495,-0.051154964 },
		{	0.011032813,0.005755223,0.047780279,0.046007354,0.122200862,0.051284455,0.051044419,0.161390901,0.141473591,-0.024310228,0.086708702,0.095941372,0.012989668,-0.154039994 },
		{	0.011017458,0.015079363,0.044392262,0.044291291,0.051284455,0.084196977,0.058156882,0.046133097,0.076913163,0.029939178,0.078088753,0.068972983,0.056352742,0.028014612 },
		{	0.009247968,0.015744939,0.043201398,0.054013912,0.051044419,0.058156882,0.092079796,0.058133345,0.091737367,0.045366004,0.064232461,0.041875444,0.0918869,-0.010726376 },
		{	-0.187006608,-0.454466075,0.125484362,0.116722301,0.161390901,0.046133097,0.058133345,4.16681385,2.65796566,-1.134650469,0.084009416,0.390790463,-0.261619508,-2.527002573 },
		{	-0.17667307,-0.715846479,0.156280622,0.180219084,0.141473591,0.076913163,0.091737367,2.65796566,4.682406426,-1.449820042,0.402556419,0.372201026,0.218418837,-2.316148996 },
		{	0.269041568,0.550790012,-0.051658023,-0.034467172,-0.024310228,0.029939178,0.045366004,-1.134650469,-1.449820042,3.636039496,0.466767967,0.661672771,0.915551245,1.899347663 },
		{	0.101834238,0.087588303,0.046725027,0.057423726,0.086708702,0.078088753,0.064232461,0.084009416,0.402556419,0.466767967,3.171270371,1.340020299,1.341677427,0.642024696 },
		{	0.058505852,0.062419761,0.051981378,0.003471095,0.095941372,0.068972983,0.041875444,0.390790463,0.372201026,0.661672771,1.340020299,3.610803843,0.442387879,0.359935045 },
		{	0.157362923,0.15511997,0.00533441,0.060668495,0.012989668,0.056352742,0.0918869,-0.261619508,0.218418837,0.915551245,1.341677427,0.442387879,3.751878262,1.120585442 },
		{	1.375810146,0.723896861,-0.060698327,-0.051154964,-0.154039994,0.028014612,-0.010726376,-2.527002573,-2.316148996,1.899347663,0.642024696,0.359935045,1.120585442,17.00507736 }
	});

	static private Matrix malVarLys = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HG2,HG3,HD2,HD3,HE2,HE3,HZ,C,CA,CB,CG,CD,CE,N,NZ
		{ 0.367121309,0.062532507,0.004121268,0.004690644,0.001090434,0.003444264,0.018341096,0.005802787,0.001296729,0.006390645,0.006332773,-0.148652032,-0.102331311,0.160853237,0.039667156,0.028898148,-0.012304786,1.069184065,-3.763871193 },
		{	0.062532507,0.195193738,0.011272421,0.006012486,0.019330254,0.020705788,0.004628004,0.007838311,0.004423411,0.005538389,0.005369531,-0.35887599,-0.619154155,0.464206696,-0.027883945,0.009580785,0.017151382,0.333582789,-4.101567745 },
		{	0.004121268,0.011272421,0.072749667,0.054673281,0.043525871,0.041609429,0.033242334,0.032213487,0.021478085,0.021482335,0.00687643,0.095966972,0.124693699,-0.06379962,0.041089356,0.013491998,0.017240513,-0.145710722,-0.549108684 },
		{	0.004690644,0.006012486,0.054673281,0.082605578,0.044222374,0.051965524,0.036628868,0.037560396,0.022796812,0.02632728,0.011047157,0.110487357,0.165404692,-0.082456134,0.052594669,0.010079783,0.026572414,-0.149214178,-0.376936585 },
		{	0.001090434,0.019330254,0.043525871,0.044222374,0.080975384,0.072466724,0.037850905,0.039911859,0.03151267,0.034436744,0.004698867,0.107882917,0.094429888,-0.01860695,0.080833383,0.004217204,0.030914901,-0.087109044,-3.4998703 },
		{	0.003444264,0.020705788,0.041609429,0.051965524,0.072466724,0.0965259,0.044206545,0.046387196,0.035857819,0.041065529,0.009124496,0.10425745,0.095117204,-0.017644435,0.08228042,0.011213314,0.032897778,-0.059915114,-0.266055673 },
		{	0.018341096,0.004628004,0.033242334,0.036628868,0.037850905,0.044206545,4.992360115,0.069541052,0.025761874,0.033027522,0.007052155,0.058029681,0.196594447,-0.024179649,0.004254587,0.107598223,0.031414464,-0.123908699,-1.565703034 },
		{	0.005802787,0.007838311,0.032213487,0.037560396,0.039911859,0.046387196,0.069541052,0.071575359,0.032259073,0.033035599,0.013237556,0.08468847,0.078394227,-0.021910701,0.01021717,0.071214669,0.025902484,-0.050493799,-1.314378619 },
		{	0.001296729,0.004423411,0.021478085,0.022796812,0.03151267,0.035857819,0.025761874,0.032259073,0.046358373,0.044494193,0.007083127,0.045381606,0.031664498,-0.019317076,0.022328079,0.017843096,0.034023933,-0.026317181,15.11536789 },
		{	0.006390645,0.005538389,0.021482335,0.02632728,0.034436744,0.041065529,0.033027522,0.033035599,0.044494193,0.056605689,0.007875184,0.039613333,0.027892381,-0.019866154,-0.001169609,0.015554182,0.046563782,-0.00349308,18.80609512 },
		{	0.006332773,0.005369531,0.00687643,0.011047157,0.004698867,0.009124496,0.007052155,0.013237556,0.007083127,0.007875184,0.095262967,-1.470523,-0.109725297,0.354304344,0.245889738,0.15706414,-0.152978033,-0.302469313,16.30794144 },
		{	-0.148652032,-0.35887599,0.095966972,0.110487357,0.107882917,0.10425745,0.058029681,0.08468847,0.045381606,0.039613333,-1.470523,5.085006714,2.805569172,-1.115717292,0.430886179,0.355721265,0.174190611,-1.142899394,35.8031311 },
		{	-0.102331311,-0.619154155,0.124693699,0.165404692,0.094429888,0.095117204,0.196594447,0.078394227,0.031664498,0.027892381,-0.109725297,2.805569172,4.865513325,-1.322877288,0.813579381,0.665118635,0.258071929,-1.300399542,-9.931623459 },
		{	0.160853237,0.464206696,-0.06379962,-0.082456134,-0.01860695,-0.017644435,-0.024179649,-0.021910701,-0.019317076,-0.019866154,0.354304344,-1.115717292,-1.322877288,3.175163984,0.339087486,0.56142205,0.394934952,1.009116888,-4.496578693 },
		{	0.039667156,-0.027883945,0.041089356,0.052594669,0.080833383,0.08228042,0.004254587,0.01021717,0.022328079,-0.001169609,0.245889738,0.430886179,0.813579381,0.339087486,2.655885935,0.071716681,0.248851925,-0.073662549,-1.903862 },
		{	0.028898148,0.009580785,0.013491998,0.010079783,0.004217204,0.011213314,0.107598223,0.071214669,0.017843096,0.015554182,0.15706414,0.355721265,0.665118635,0.56142205,0.071716681,1.876264691,0.356755585,-0.045868911,-5.952273846 },
		{	-0.012304786,0.017151382,0.017240513,0.026572414,0.030914901,0.032897778,0.031414464,0.025902484,0.034023933,0.046563782,-0.152978033,0.174190611,0.258071929,0.394934952,0.248851925,0.356755585,1.193255901,-0.188530088,7.958240509 },
		{	1.069184065,0.333582789,-0.145710722,-0.149214178,-0.087109044,-0.059915114,-0.123908699,-0.050493799,-0.026317181,-0.00349308,-0.302469313,-1.142899394,-1.300399542,1.009116888,-0.073662549,-0.045868911,-0.188530088,15.94315529,-35.75146103 },
		{	-3.763871193,-4.101567745,-0.549108684,-0.376936585,-3.4998703,-0.266055673,-1.565703034,-1.314378619,15.11536789,18.80609512,16.30794144,35.8031311,-9.931623459,-4.496578693,-1.903862,-5.952273846,7.958240509,-35.75146103,1375.68103 }
	});

	static private Matrix malVarMet = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HG2,HG3,HE,C,CA,CB,CG,CE,N
		{ 0.379910737,0.073540278,0.033204105,0.020433428,0.006451493,0.018314024,0.007794171,-0.075774916,-0.10517633,0.194674715,-0.000527668,0.01284879,1.036224484 },
		{	0.073540278,0.236991897,0.035211787,0.038094997,0.039034139,0.052051544,0.045107599,-0.272179902,-0.695379257,0.348967612,0.12472634,0.18072775,0.331306279 },
		{	0.033204105,0.035211787,0.167457789,0.109973155,0.118740946,0.121467002,0.154245541,0.161310509,0.125277892,0.050280865,0.16222766,0.081022255,-0.11221502 },
		{	0.020433428,0.038094997,0.109973155,0.147581056,0.088801868,0.106410846,0.109937541,0.098233409,0.096929945,0.02276622,0.195842505,0.006073722,-0.044454228 },
		{	0.006451493,0.039034139,0.118740946,0.088801868,0.205239192,0.169335976,0.196313754,0.15497677,0.065145746,0.080463611,0.207901016,0.126820907,-0.23334302 },
		{	0.018314024,0.052051544,0.121467002,0.106410846,0.169335976,0.242941648,0.212639391,0.136581704,0.06556461,0.106728241,0.278554857,0.282053202,-0.112973683 },
		{	0.007794171,0.045107599,0.154245541,0.109937541,0.196313754,0.212639391,0.27474153,0.106673032,0.034212198,0.159190983,0.165893227,0.109454334,-0.048359267 },
		{	-0.075774916,-0.272179902,0.161310509,0.098233409,0.15497677,0.136581704,0.106673032,4.178848267,2.243742466,-1.604590297,0.312306047,-0.198460132,-1.816891432 },
		{	-0.10517633,-0.695379257,0.125277892,0.096929945,0.065145746,0.06556461,0.034212198,2.243742466,4.969119549,-0.704387784,0.444886476,-0.372276515,-1.372543097 },
		{	0.194674715,0.348967612,0.050280865,0.02276622,0.080463611,0.106728241,0.159190983,-1.604590297,-0.704387784,5.353907108,0.317944616,0.352276415,1.069101572 },
		{	-0.000527668,0.12472634,0.16222766,0.195842505,0.207901016,0.278554857,0.165893227,0.312306047,0.444886476,0.317944616,3.985911846,0.456732452,-0.338241875 },
		{	0.01284879,0.18072775,0.081022255,0.006073722,0.126820907,0.282053202,0.109454334,-0.198460132,-0.372276515,0.352276415,0.456732452,11.18597889,0.2225793 },
		{	1.036224484,0.331306279,-0.11221502,-0.044454228,-0.23334302,-0.112973683,-0.048359267,-1.816891432,-1.372543097,1.069101572,-0.338241875,0.2225793,20.99051857 }
	});

	static private Matrix malVarPhe = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HD1,HD2,HE1,HE2,HZ,C,CA,CB,CG,CD1,CD2,CE1,CE2,CZ,N
		{ 0.543549538,0.153633237,0.006905453,0.014116059,0.016036941,0.015260615,-0.010345147,-0.012876884,-0.033586852,-0.180800453,-0.186233267,0.349561602,0.166688994,0.001640222,0.014371216,-0.085852519,-0.087689489,-0.155288622,1.614772797 },
		{	0.153633237,6.998471737,-0.000138866,0.004275927,0.028231494,0.030358732,0.034367185,0.041801319,0.008654501,-0.465769947,-1.136533141,0.648683906,0.228754938,0.069748826,0.091341101,-0.293262899,-0.419885099,-0.236114994,0.110386431 },
		{	0.006905453,-0.000138866,0.156688362,0.06814336,0.058801223,0.057398733,0.023001006,0.025360024,0.018439043,0.151408419,0.158458233,-0.124513038,0.093792491,0.027861331,0.062565915,0.103985615,0.162798911,0.00486455,-0.03623924 },
		{	0.014116059,0.004275927,0.06814336,0.212764829,0.060103133,0.061259147,0.026036479,0.022871444,0.021206178,0.186362222,0.195705712,-0.144533813,-0.147607297,0.033495911,0.02305541,0.114519127,0.127706736,0.028226338,-0.112925693 },
		{	0.016036941,0.028231494,0.058801223,0.060103133,0.144898683,0.137386218,0.066180773,0.058730401,0.055637024,0.148493916,0.067915909,-0.002022276,-0.011685636,0.085737653,0.068103291,0.137021914,0.145711064,0.081009239,0.019108253 },
		{	0.015260615,0.030358732,0.057398733,0.061259147,0.137386218,0.140606955,0.072371997,0.06683521,0.06124248,0.114432253,0.045469925,-0.014423213,-0.011685636,0.071193628,0.070719548,0.126550496,0.137203828,0.060659707,0.004745624 },
		{	-0.010345147,0.034367185,0.023001006,0.026036479,0.066180773,0.072371997,0.163978621,0.15066883,0.147632137,0.091954559,0.055586267,-0.030307509,-0.040184412,0.066204712,0.046088323,0.156555012,0.146133557,0.336455792,-0.047151856 },
		{	-0.012876884,0.041801319,0.025360024,0.022871444,0.058730401,0.06683521,0.15066883,0.143551081,0.151753187,0.067149781,0.048767034,-0.036008757,-0.040184412,0.043506514,0.04687196,0.151191771,0.146071717,0.361023396,-0.051001336 },
		{	-0.033586852,0.008654501,0.018439043,0.021206178,0.055637024,0.06124248,0.147632137,0.151753187,1.584564209,0.12000142,0.247112811,-0.032287572,-0.081123859,0.058456611,0.045260321,0.121702477,0.112187043,0.424770922,-0.220938608 },
		{	-0.180800453,-0.465769947,0.151408419,0.186362222,0.148493916,0.114432253,0.091954559,0.067149781,0.12000142,5.993542671,2.9839468,-1.307312846,-0.273788244,0.28660968,0.05117362,0.251683921,-0.250434548,0.266022503,-0.692630947 },
		{	-0.186233267,-1.136533141,0.158458233,0.195705712,0.067915909,0.045469925,0.055586267,0.048767034,0.247112811,2.9839468,7.354676247,-1.737214565,-0.674133658,0.48930797,0.321583331,1.396826983,1.590946317,0.866353035,-0.376057118 },
		{	0.349561602,0.648683906,-0.124513038,-0.144533813,-0.002022276,-0.014423213,-0.030307509,-0.036008757,-0.032287572,-1.307312846,-1.737214565,4.394043446,0.294051409,0.515188158,0.336122453,-0.495895922,-0.983998537,-0.403524578,0.700869799 },
		{	0.166688994,0.228754938,0.093792491,-0.147607297,-0.011685636,-0.011685636,-0.040184412,-0.040184412,-0.081123859,-0.273788244,-0.674133658,0.294051409,1.03084743,0.66493398,0.66493398,0.193338588,0.193338588,-0.101259418,-0.489985287 },
		{	0.001640222,0.069748826,0.027861331,0.033495911,0.085737653,0.071193628,0.066204712,0.043506514,0.058456611,0.28660968,0.48930797,0.515188158,0.66493398,1.738998413,1.695225835,0.73507297,0.70740211,0.53402859,-0.471299887 },
		{	0.014371216,0.091341101,0.062565915,0.02305541,0.068103291,0.070719548,0.046088323,0.04687196,0.045260321,0.05117362,0.321583331,0.336122453,0.66493398,1.695225835,1.695531964,0.709843755,0.708992958,0.568887413,-0.476287842 },
		{	-0.085852519,-0.293262899,0.103985615,0.114519127,0.137021914,0.126550496,0.156555012,0.151191771,0.121702477,0.251683921,1.396826983,-0.495895922,0.193338588,0.73507297,0.709843755,29.72649384,43.78829575,1.112157345,0.85968858 },
		{	-0.087689489,-0.419885099,0.162798911,0.127706736,0.145711064,0.137203828,0.146133557,0.146071717,0.112187043,-0.250434548,1.590946317,-0.983998537,0.193338588,0.70740211,0.708992958,43.78829575,43.3463707,1.167173147,1.461098075 },
		{	-0.155288622,-0.236114994,0.00486455,0.028226338,0.081009239,0.060659707,0.336455792,0.361023396,0.424770922,0.266022503,0.866353035,-0.403524578,-0.101259418,0.53402859,0.568887413,1.112157345,1.167173147,14.25286484,-0.208609492 },
		{	1.614772797,0.110386431,-0.03623924,-0.112925693,0.019108253,0.004745624,-0.047151856,-0.051001336,-0.220938608,-0.692630947,-0.376057118,0.700869799,-0.489985287,-0.471299887,-0.476287842,0.85968858,1.461098075,-0.208609492,19.08541489 }
	});

	static private Matrix malVarPro = new Matrix(new double[][] {
		//HA,HB2,HB3,HG2,HG3,HD2,HD3,C,CA,CB,CG,CD,N
		{ 0.127948582,0.047235888,0.056189362,0.03332131,0.037042987,0.032584723,0.036460623,-0.04755611,-0.109820783,0.073510021,-0.022358265,0.03069205,0.387137532 },
		{	0.047235888,0.125374019,0.052163582,0.055185419,0.044674143,0.051821236,0.023038918,0.074782223,0.05664571,0.048317723,0.014355249,0.064463228,0.128864378 },
		{	0.056189362,0.052163582,0.158007279,0.053368233,0.07311637,0.033230692,0.069313638,0.069562271,0.076943889,0.074731596,0.027263019,0.057429213,-0.178820118 },
		{	0.03332131,0.055185419,0.053368233,0.111212038,0.097072661,0.065490454,0.06369663,0.05691528,0.081356481,0.03318787,0.0773146,0.070018172,-0.196720749 },
		{	0.037042987,0.044674143,0.07311637,0.097072661,0.133993655,0.057497066,0.085908271,0.070056014,0.043164812,0.082001917,0.099156082,0.094146259,-0.224820033 },
		{	0.032584723,0.051821236,0.033230692,0.065490454,0.057497066,0.149486661,0.094618753,0.061851088,0.086105719,0.050814983,0.058313724,0.164076403,0.302142292 },
		{	0.036460623,0.023038918,0.069313638,0.06369663,0.085908271,0.094618753,0.17821686,0.029822048,0.101648718,0.065006174,0.051942363,0.161657929,-0.291708231 },
		{	-0.04755611,0.074782223,0.069562271,0.05691528,0.070056014,0.061851088,0.029822048,2.570146322,0.99639988,-0.185524568,0.492183268,0.024638675,1.168789625 },
		{	-0.109820783,0.05664571,0.076943889,0.081356481,0.043164812,0.086105719,0.101648718,0.99639988,3.507337093,-0.476301968,0.62570852,0.449263603,0.324586749 },
		{	0.073510021,0.048317723,0.074731596,0.03318787,0.082001917,0.050814983,0.065006174,-0.185524568,-0.476301968,2.411034823,-0.050461303,0.312410653,0.0303312 },
		{	-0.022358265,0.014355249,0.027263019,0.0773146,0.099156082,0.058313724,0.051942363,0.492183268,0.62570852,-0.050461303,1.319811702,0.401096851,2.05501771 },
		{	0.03069205,0.064463228,0.057429213,0.070018172,0.094146259,0.164076403,0.161657929,0.024638675,0.449263603,0.312410653,0.401096851,3.156873703,1.674100757 },
		{	0.387137532,0.128864378,-0.178820118,-0.196720749,-0.224820033,0.302142292,-0.291708231,1.168789625,0.324586749,0.0303312,2.05501771,1.674100757,88.07623291 }
	});

	static private Matrix malVarSer = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HG,C,CA,CB,N
		{ 0.398513109,0.04623181,0.016665854,0.022241443,0.046292558,0.056789555,0.032011122,-0.022381591,1.104091644 },
		{	0.04623181,0.183807597,0.001240865,0.001217798,-0.071638539,-0.230514571,-0.468509942,0.377238542,0.232677847 },
		{	0.016665854,0.001240865,0.080144256,0.052704539,0.032950364,0.092147455,0.0897751,-0.030368004,0.0114533 },
		{	0.022241443,0.001217798,0.052704539,0.094000556,0.000357445,0.108926728,0.116596431,-0.039312188,-0.051076565 },
		{	0.046292558,-0.071638539,0.032950364,0.000357445,1.62681365,0.625875235,0.449889183,0.51812619,-0.554987013 },
		{	0.056789555,-0.230514571,0.092147455,0.108926728,0.625875235,3.300351858,1.80311513,-0.833756506,-0.199274048 },
		{	0.032011122,-0.468509942,0.0897751,0.116596431,0.449889183,1.80311513,4.545715809,-1.266839624,-0.29854995 },
		{	-0.022381591,0.377238542,-0.030368004,-0.039312188,0.51812619,-0.833756506,-1.266839624,5.087539196,0.381844163 },
		{	1.104091644,0.232677847,0.0114533,-0.051076565,-0.554987013,-0.199274048,-0.29854995,0.381844163,14.38586426 }
	});

	static private Matrix malVarThr = new Matrix(new double[][] {
		//H,HA,HB,HG1,HG2,C,CA,CB,CG2,N
		{ 0.399677485,0.079332367,5.31825E-05,-0.055077191,0.00865848,-0.092531294,-0.054172218,0.066410445,-0.002123201,1.294419646 },
		{	0.079332367,0.237935677,0.002027369,-0.010361892,0.00212599,-0.314469934,-0.786431372,0.433335424,-0.046037499,0.171396822 },
		{	5.31825E-05,0.002027369,0.126356199,0.072322309,0.039713461,0.130247355,-0.079461716,0.036667526,0.052739848,-0.510240972 },
		{	-0.055077191,-0.010361892,0.072322309,2.649239779,0.03939411,0.111775741,0.900414348,-0.265966266,0.642437577,0.054507546 },
		{	0.00865848,0.00212599,0.039713461,0.03939411,0.061567552,0.076484963,0.061861191,0.011568365,0.08149793,-0.079259321 },
		{	-0.092531294,-0.314469934,0.130247355,0.111775741,0.076484963,3.074912071,1.993779779,-0.467184514,0.635851085,-1.260207892 },
		{	-0.054172218,-0.786431372,-0.079461716,0.900414348,0.061861191,1.993779779,6.733168602,-1.653884053,0.847847939,2.164549828 },
		{	0.066410445,0.433335424,0.036667526,-0.265966266,0.011568365,-0.467184514,-1.653884053,7.415740013,0.192319259,-0.84431541 },
		{	-0.002123201,-0.046037499,0.052739848,0.642437577,0.08149793,0.635851085,0.847847939,0.192319259,3.047462463,0.026707284 },
		{	1.294419646,0.171396822,-0.510240972,0.054507546,-0.079259321,-1.260207892,2.164549828,-0.84431541,0.026707284,25.3979454 }
	});

	static private Matrix malVarTrp = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HD1,HE1,HE3,HZ2,HZ3,HH2,C,CA,CB,CG,CD1,CD2,CE2,CE3,CZ2,CZ3,CH2,N,NE1
		{ 0.661329746,0.132090196,0.020765161,0.015894927,0.007389797,0.006906026,-0.010167865,-0.015487382,-0.037558824,-0.015786661,0.009516691,0.00665119,0.441847771,0.104767002,-0.190362752,-2.114088535,-0.017072132,0.129406199,-0.272973567,-0.071197748,0.535183191,2.106140375,-0.287125439 },
		{	0.132090196,0.315868825,0.014522251,0.017121641,0.004743131,0.000315615,0.008252796,0.0011519,-0.016208008,0.009290006,-0.263874203,-0.887101293,0.612602413,-0.078827515,-0.193338186,-0.514159858,1.980393648,-0.041501593,0.270474821,0.351163,0.115935512,0.318475395,0.126986861 },
		{	0.020765161,0.014522251,0.126530409,0.064015567,0.035533153,0.028172933,0.032624327,0.013270613,0.013702227,0.013742022,0.133945242,0.172670007,-0.157479942,0.030200236,-0.036088325,-0.001207251,-0.246646836,0.000094689,-0.085696429,-0.07762678,0.130246118,0.019535713,-0.027619368 },
		{	0.015894927,0.017121641,0.064015567,0.148985609,0.053458635,0.01812847,0.060853973,0.029651206,0.027186869,0.023641719,0.11944776,0.228025615,-0.039295558,-0.251549989,0.116067663,-0.167012751,-0.385442525,0.011529104,-0.333288223,-0.341743052,0.331099331,0.038808439,-0.330518425 },
		{	0.007389797,0.004743131,0.035533153,0.053458635,0.113754526,0.049717538,0.027461793,0.027316304,0.020764226,0.026383638,0.052310664,0.116902784,-0.046868015,-0.003455273,0.23430413,0.439785689,-0.358501822,0.051015008,-0.061566491,-0.076822713,0.051828314,-0.03581531,0.053032141 },
		{	0.006906026,0.000315615,0.028172933,0.01812847,0.049717538,0.409550905,0.011688895,0.057730421,0.023747465,0.036362756,0.00091709,0.085936502,-0.134609759,-0.144362241,0.11515411,-0.057400324,-1.2027601,0.028360447,0.138085321,-0.17038846,0.039613932,0.037227172,0.793321014 },
		{	-0.010167865,0.008252796,0.032624327,0.060853973,0.027461793,0.011688895,0.208750501,0.048835624,0.079881579,0.061424799,0.096131295,0.198998958,-0.095802173,-0.288267165,0.171279773,0.027484631,0.026160657,0.1143867,-0.028764701,-0.039241124,0.088730782,-0.164604455,-0.107454732 },
		{	-0.015487382,0.0011519,0.013270613,0.029651206,0.027316304,0.057730421,0.048835624,0.130023524,0.044330705,0.072504178,-0.011085736,-0.006370402,-0.009878446,0.111533552,0.090558007,0.461490721,-0.117983706,0.067999832,0.329961509,0.289491892,0.069931589,-0.124593109,0.07156311 },
		{	-0.037558824,-0.016208008,0.013702227,0.027186869,0.020764226,0.023747465,0.079881579,0.044330705,0.163874626,0.095901363,-0.022358105,0.106238894,-0.110912964,-0.057450336,0.146114633,0.029011229,0.31572932,0.039704789,0.085357972,0.137192562,0.037278,-0.129124865,0.186238989 },
		{	-0.015786661,0.009290006,0.013742022,0.023641719,0.026383638,0.036362756,0.061424799,0.072504178,0.095901363,0.192525551,-0.07654839,-0.052928962,-0.01324157,-0.066366673,0.169071585,-0.010524049,-0.957291126,0.154791027,0.334657878,0.25467059,-0.018785745,-0.103453443,0.082332879 },
		{	0.009516691,-0.263874203,0.133945242,0.11944776,0.052310664,0.00091709,0.096131295,-0.011085736,-0.022358105,-0.07654839,3.631575346,2.33945322,-0.870782912,0.714103282,-0.362164468,-0.909205318,0.300866813,-0.338301599,-0.155202195,0.197302043,0.452268452,-1.119035602,-0.405825079 },
		{	0.00665119,-0.887101293,0.172670007,0.228025615,0.116902784,0.085936502,0.198998958,-0.006370402,0.106238894,-0.052928962,2.33945322,6.004242897,-1.66727674,0.006123972,0.786833108,-1.441877246,-4.484669209,0.337298572,-1.732644081,-2.255311251,0.719937444,-0.596547902,-1.332642913 },
		{	0.441847771,0.612602413,-0.157479942,-0.039295558,-0.046868015,-0.134609759,-0.095802173,-0.009878446,-0.110912964,-0.01324157,-0.870782912,-1.66727674,4.448700905,2.439207792,0.308979452,-1.835621119,-0.137719721,0.224739924,1.535282612,1.313479066,0.70079422,1.353014827,-0.322219372 },
		{	0.104767002,-0.078827515,0.030200236,-0.251549989,-0.003455273,-0.144362241,-0.288267165,0.111533552,-0.057450336,-0.066366673,0.714103282,0.006123972,2.439207792,1.620525003,-0.148247734,1.613602638,0.909652352,0.676803649,2.493831396,3.073373795,0.18686451,0.523722351,-1.175410509 },
		{	-0.190362752,-0.193338186,-0.036088325,0.116067663,0.23430413,0.11515411,0.171279773,0.090558007,0.146114633,0.169071585,-0.362164468,0.786833108,0.308979452,-0.148247734,2.928669691,-1.145414114,-0.637731433,0.909006298,-0.447238296,-0.801229835,-0.317866266,-1.37936008,0.427921981 },
		{	-2.114088535,-0.514159858,-0.001207251,-0.167012751,0.439785689,-0.057400324,0.027484631,0.461490721,0.029011229,-0.010524049,-0.909205318,-1.441877246,-1.835621119,1.613602638,-1.145414114,8.452910423,7.463749886,-1.571911931,1.667182207,0.614959359,-1.883159995,-12.39416313,-0.67500037 },
		{	-0.017072132,1.980393648,-0.246646836,-0.385442525,-0.358501822,-1.2027601,0.026160657,-0.117983706,0.31572932,-0.957291126,0.300866813,-4.484669209,-0.137719721,0.909652352,-0.637731433,7.463749886,39.61133194,0.107531481,-4.3554883,-0.460731298,-6.877117634,4.477484226,-0.725069404 },
		{	0.129406199,-0.041501593,0.000094689,0.011529104,0.051015008,0.028360447,0.1143867,0.067999832,0.039704789,0.154791027,-0.338301599,0.337298572,0.224739924,0.676803649,0.909006298,-1.571911931,0.107531481,4.328186035,3.124161243,5.577692986,0.807518184,-0.044028614,-1.879525542 },
		{	-0.272973567,0.270474821,-0.085696429,-0.333288223,-0.061566491,0.138085321,-0.028764701,0.329961509,0.085357972,0.334657878,-0.155202195,-1.732644081,1.535282612,2.493831396,-0.447238296,1.667182207,-4.3554883,3.124161243,57.56800079,66.62944031,-1.153520823,-1.387021303,-0.360761434 },
		{	-0.071197748,0.351163,-0.07762678,-0.341743052,-0.076822713,-0.17038846,-0.039241124,0.289491892,0.137192562,0.25467059,0.197302043,-2.255311251,1.313479066,3.073373795,-0.801229835,0.614959359,-0.460731298,5.577692986,66.62944031,72.58539581,0.638285101,-1.010909796,2.547362328 },
		{	0.535183191,0.115935512,0.130246118,0.331099331,0.051828314,0.039613932,0.088730782,0.069931589,0.037278,-0.018785745,0.452268452,0.719937444,0.70079422,0.18686451,-0.317866266,-1.883159995,-6.877117634,0.807518184,-1.153520823,0.638285101,13.86545849,3.965545416,-2.949623108 },
		{	2.106140375,0.318475395,0.019535713,0.038808439,-0.03581531,0.037227172,-0.164604455,-0.124593109,-0.129124865,-0.103453443,-1.119035602,-0.596547902,1.353014827,0.523722351,-1.37936008,-12.39416313,4.477484226,-0.044028614,-1.387021303,-1.010909796,3.965545416,19.75927353,0.37001276 },
		{	-0.287125439,0.126986861,-0.027619368,-0.330518425,0.053032141,0.793321014,-0.107454732,0.07156311,0.186238989,0.082332879,-0.405825079,-1.332642913,-0.322219372,-1.175410509,0.427921981,-0.67500037,-0.725069404,-1.879525542,-0.360761434,2.547362328,-2.949623108,0.37001276,57.28811646 }
	});

	static private Matrix malVarTyr = new Matrix(new double[][] {
		//H,HA,HB2,HB3,HD1,HD2,HE1,HE2,HH,C,CA,CB,CG,CD1,CD2,CE1,CE2,CZ,N
		{ 0.593182266,0.108372688,-0.013951996,-0.009172456,-0.002041235,-0.003607854,-0.009192387,-0.017190138,0.245930985,-0.151328787,-0.083633415,0.421942502,-0.090605065,0.151859522,0.140021354,-0.059875958,-0.139920935,-1.316010356,1.680685997 },
		{	0.108372688,0.322918624,0.001834079,-0.00616676,0.018064331,0.0209044,0.00050226,0.001345329,0.060590621,-0.350153714,-0.988772869,0.648959935,-0.048856244,0.101504132,0.320888847,0.059629548,0.099672422,-2.212325811,0.185940728 },
		{	-0.013951996,0.001834079,0.153599635,0.072728738,0.05062601,0.051618215,0.018540761,0.018409425,-0.119642891,0.100123026,0.136481628,-0.116533265,-0.010560672,-0.060096137,-0.142275274,0.07844501,0.052260451,-0.611113429,-0.219174713 },
		{	-0.009172456,-0.00616676,0.072728738,0.165575817,0.048222464,0.052226346,0.017602183,0.018124726,0.16217871,0.134526715,0.19755052,-0.129450366,0.005388705,-0.033480365,-0.061781149,0.050454345,0.055690955,0.466223657,-0.187072247 },
		{	-0.002041235,0.018064331,0.05062601,0.048222464,0.094594829,0.091209106,0.038927071,0.03812483,0.15082325,0.059667252,0.05599599,-0.015689598,-0.022359747,0.051453389,0.022639947,0.037207507,0.046747167,0.102732278,-0.079012409 },
		{	-0.003607854,0.0209044,0.051618215,0.052226346,0.091209106,0.094311781,0.037860513,0.038628887,0.131953299,0.059250742,0.051216427,-0.009852424,-0.021204097,0.025891474,0.02825664,0.01173131,0.033259351,0.102732278,-0.08195705 },
		{	-0.009192387,0.00050226,0.018540761,0.017602183,0.038927071,0.037860513,0.066373296,0.063802227,0.216514826,0.033907067,0.057463553,-0.012825001,0.025955677,0.033018608,-0.029791443,0.124814935,0.080434352,0.520955443,-0.01878001 },
		{	-0.017190138,0.001345329,0.018409425,0.018124726,0.03812483,0.038628887,0.063802227,0.064408228,0.298426837,0.041355856,0.062579192,-0.018979991,0.02665052,-0.01729692,-0.023091208,0.063785479,0.080633827,0.520955443,-0.042288218 },
		{	0.245930985,0.060590621,-0.119642891,0.16217871,0.15082325,0.131953299,0.216514826,0.298426837,3.650907278,0.58292824,0.041142989,-0.523603141,0,1.71144414,-0.2799384,1.974590302,0.513059557,0,1.305423975 },
		{	-0.151328787,-0.350153714,0.100123026,0.134526715,0.059667252,0.059250742,0.033907067,0.041355856,0.58292824,3.89579773,2.77870822,-1.214239478,0.453299373,0.018813076,-1.071421146,1.494295001,0.82475394,-0.01217334,-0.694135666 },
		{	-0.083633415,-0.988772869,0.136481628,0.19755052,0.05599599,0.051216427,0.057463553,0.062579192,0.041142989,2.77870822,6.368896961,-1.413163185,0.402646303,0.50013119,-1.261783361,1.00295496,0.277997166,-1.803325057,-0.854195356 },
		{	0.421942502,0.648959935,-0.116533265,-0.129450366,-0.015689598,-0.009852424,-0.012825001,-0.018979991,-0.523603141,-1.214239478,-1.413163185,4.830979824,-0.014666396,1.054337621,0.596610606,0.812415302,0.471265346,-6.128417015,0.839488387 },
		{	-0.090605065,-0.048856244,-0.010560672,0.005388705,-0.022359747,-0.021204097,0.025955677,0.02665052,0,0.453299373,0.402646303,-0.014666396,1.438317895,0.087459005,0.142365769,0.313322663,0.309906155,0.032700528,-1.02494061 },
		{	0.151859522,0.101504132,-0.060096137,-0.033480365,0.051453389,0.025891474,0.033018608,-0.01729692,1.71144414,0.018813076,0.50013119,1.054337621,0.087459005,30.16939735,33.36718369,6.159466267,-0.055209424,-2.146585226,-0.428141683 },
		{	0.140021354,0.320888847,-0.142275274,-0.061781149,0.022639947,0.02825664,-0.029791443,-0.023091208,-0.2799384,-1.071421146,-1.261783361,0.596610606,0.142365769,33.36718369,34.10924912,-0.159435526,-0.084375605,-2.42848444,-0.21037142 },
		{	-0.059875958,0.059629548,0.07844501,0.050454345,0.037207507,0.01173131,0.124814935,0.063785479,1.974590302,1.494295001,1.00295496,0.812415302,0.313322663,6.159466267,-0.159435526,11.67894077,6.174175263,-2.897614718,-0.747496188 },
		{	-0.139920935,0.099672422,0.052260451,0.055690955,0.046747167,0.033259351,0.080434352,0.080633827,0.513059557,0.82475394,0.277997166,0.471265346,0.309906155,-0.055209424,-0.084375605,6.174175263,6.190960407,-3.171273947,-0.795468032 },
		{	-1.316010356,-2.212325811,-0.611113429,0.466223657,0.102732278,0.102732278,0.520955443,0.520955443,0,-0.01217334,-1.803325057,-6.128417015,0.032700528,-2.146585226,-2.42848444,-2.897614718,-3.171273947,40.32577133,-6.926008225 },
		{	1.680685997,0.185940728,-0.219174713,-0.187072247,-0.079012409,-0.08195705,-0.01878001,-0.042288218,1.305423975,-0.694135666,-0.854195356,0.839488387,-1.02494061,-0.428141683,-0.21037142,-0.747496188,-0.795468032,-6.926008225,20.13540649 }
	});

	static private Matrix malVarVal = new Matrix(new double[][] {
		//H,HA,HB,HG1,HG2,C,CA,CB,CG1,CG2,N
		{ 0.474454433,0.124050438,-0.011127413,0.010563846,0.002759714,-0.231536984,-0.385617137,0.297521889,-0.040059399,0.007962246,1.448510766 },
		{	0.124050438,0.354129314,0.002574488,0.013190175,0.005394742,-0.557517707,-1.336580992,0.675501943,-0.141067296,-0.30491674,0.029538153 },
		{	-0.011127413,0.002574488,0.102354877,0.046423148,0.056876943,0.138835639,0.195689172,-0.089964628,0.071880579,0.04024864,-0.309310794 },
		{	0.010563846,0.013190175,0.046423148,0.082328841,0.061420683,0.06349805,0.116302341,-0.008479784,0.106810585,0.046158329,-0.034708511 },
		{	0.002759714,0.005394742,0.056876943,0.061420683,0.104502946,0.117281072,0.174566284,-0.03354777,0.048513815,0.135745823,-0.075891838 },
		{	-0.231536984,-0.557517707,0.138835639,0.06349805,0.117281072,3.640900135,3.51388526,-1.325410605,0.640890002,1.176813245,-0.750159442 },
		{	-0.385617137,-1.336580992,0.195689172,0.116302341,0.174566284,3.51388526,8.229063988,-2.851556301,1.332353354,2.424005747,0.063049749 },
		{	0.297521889,0.675501943,-0.089964628,-0.008479784,-0.03354777,-1.325410605,-2.851556301,3.418505669,0.104608432,-0.384231836,-0.127606899 },
		{	-0.040059399,-0.141067296,0.071880579,0.106810585,0.048513815,0.640890002,1.332353354,0.104608432,6.466031551,0.824112415,0.081443407 },
		{	0.007962246,-0.30491674,0.04024864,0.046158329,0.135745823,1.176813245,2.424005747,-0.384231836,0.824112415,3.187404156,1.213735223 },
		{	1.448510766,0.029538153,-0.309310794,-0.034708511,-0.075891838,-0.750159442,0.063049749,-0.127606899,0.081443407,1.213735223,22.49996376 }
	});

	static private Matrix malVarUnk = new Matrix(new double[][] {
		//H,HA,C,CA,CB,N
		{ 506.25, 0, 0, 0, 0, 0 }, {
			0, 506.25, 0, 0, 0, 0 }, {
			0, 0, 40000, 0, 0, 0 }, {
			0, 0, 0, 40000, 0, 0 }, {
			0, 0, 0, 0, 40000, 0 }, {
			0, 0, 0, 0, 0, 10000 }, });

    public static Matrix[] malVar = new Matrix[] { malVarAla, malVarArg, malVarAsp, malVarAsn, malVarCys, malVarGlu, malVarGln, malVarGly, malVarHis, malVarIle, malVarLeu, malVarLys, malVarMet, malVarPhe, malVarPro, malVarSer, malVarThr, malVarTrp, malVarTyr, malVarVal, malVarUnk };

    //--------------------------------------bmrb standard deviations-------------------------------------
    static private Matrix bmrbSdAla = new Matrix(new double[] { 0.61, 0.43, 0.25, 2.13, 2.04, 1.88, 3.69 }, dimAla.length);
    static private Matrix bmrbSdArg = new Matrix(new double[] { 0.6, 0.45, 0.27, 0.28, 0.27, 0.28, 0.23, 0.24, 0.57, 0.39, 0.35, 0.42, 0.4, 2.04, 2.39, 1.83, 1.39, 1.04, 0.98, 3.88, 14.8, 6.39, 6.9 }, dimArg.length);
    static private Matrix bmrbSdAsp = new Matrix(new double[] { 0.58, 0.32, 0.27, 0.29, 1.77, 2.09, 1.66, 1.57, 4.09 }, dimAsp.length);
    static private Matrix bmrbSdAsn = new Matrix(new double[] { 0.63, 0.37, 0.33, 0.34, 0.52, 0.52, 1.82, 1.97, 1.8, 1.34, 4.26, 2.51 }, dimAsn.length);
    static private Matrix bmrbSdCys = new Matrix(new double[] { 0.67, 0.57, 0.45, 0.48, 2.54, 2.04, 3.41, 6.67, 4.61 }, dimCys.length);
    static private Matrix bmrbSdGlu = new Matrix(new double[] { 0.61, 0.42, 0.22, 0.22, 0.22, 0.22, 2.01, 2.14, 1.79, 1.37, 1.91, 3.7 }, dimGlu.length);
    static private Matrix bmrbSdGln = new Matrix(new double[] { 0.6, 0.44, 0.27, 0.29, 0.29, 0.29, 0.49, 0.49, 1.96, 2.2, 1.91, 1.23, 1.08, 3.84, 2.11 }, dimGln.length);
    static private Matrix bmrbSdGly = new Matrix(new double[] { 0.7, 0.39, 0.38, 1.86, 1.36, 4.19 }, dimGly.length);
    static private Matrix bmrbSdHis = new Matrix(new double[] { 0.69, 0.48, 0.39, 0.4, 3.01, 0.49, 0.55, 2.73, 2.05, 2.47, 2.19, 3.35, 2.92, 2.47, 4.32, 34.07, 20.55 }, dimHis.length);
    static private Matrix bmrbSdIle = new Matrix(new double[] { 0.7, 0.56, 0.3, 0.39, 0.41, 0.27, 0.3, 1.95, 2.78, 2.09, 2.17, 1.55, 1.78, 4.46 }, dimIle.length);
    static private Matrix bmrbSdLeu = new Matrix(new double[] { 0.65, 0.47, 0.35, 0.36, 0.33, 0.28, 0.28, 2.04, 2.2, 1.92, 1.27, 1.77, 1.8, 4 }, dimLeu.length);
    static private Matrix bmrbSdLys = new Matrix(new double[] { 0.63, 0.45, 0.26, 0.27, 0.27, 0.29, 0.26, 0.25, 0.21, 0.22, 0.37, 2.18, 2.26, 1.86, 1.24, 1.26, 0.91, 3.97, 50.29 }, dimLys.length);
    static private Matrix bmrbSdMet = new Matrix(new double[] { 0.59, 0.47, 0.35, 0.37, 0.35, 0.39, 0.41, 2.09, 2.28, 2.28, 1.32, 2.89, 3.71 }, dimMet.length);
    static private Matrix bmrbSdPhe = new Matrix(new double[] { 0.72, 0.58, 0.37, 0.38, 0.62, 0.67, 0.62, 0.66, 0.66, 2.02, 2.7, 2.09, 3.04, 1.4, 1.33, 1.61, 1.03, 1.76, 4.3 }, dimPhe.length);
    static private Matrix bmrbSdPro = new Matrix(new double[] { 0.34, 0.36, 0.37, 0.34, 0.35, 0.36, 0.39, 1.57, 1.64, 1.26, 1.14, 1.17, 10.03 }, dimPro.length);
    static private Matrix bmrbSdSer = new Matrix(new double[] { 0.61, 0.42, 0.28, 0.29, 1.14, 1.76, 2.18, 1.63, 3.82 }, dimSer.length);
    static private Matrix bmrbSdThr = new Matrix(new double[] { 0.62, 0.48, 0.35, 1.76, 0.25, 1.78, 2.72, 2.04, 1.29, 4.99 }, dimThr.length);
    static private Matrix bmrbSdTrp = new Matrix(new double[] { 0.81, 0.55, 0.36, 0.36, 0.34, 0.56, 0.81, 0.69, 0.81, 0.75, 1.95, 2.61, 2.17, 1.84, 2.07, 1.37, 6.64, 1.96, 1.55, 1.95, 1.62, 4.55, 2.4 }, dimTrp.length);
    static private Matrix bmrbSdTyr = new Matrix(new double[] { 0.76, 0.57, 0.38, 0.38, 0.51, 0.54, 0.44, 0.47, 1.59, 2.01, 2.61, 2.21, 2.32, 1.35, 1.62, 1.6, 1.85, 2.28, 4.54 }, dimTyr.length);
    static private Matrix bmrbSdVal = new Matrix(new double[] { 0.7, 0.58, 0.32, 0.26, 0.29, 1.95, 2.98, 1.84, 1.49, 1.66, 4.85 }, dimVal.length);
    static private Matrix bmrbSdUnk = new Matrix(new double[] { 22.5, 22.5, 200, 200, 200, 100 }, dimUnk.length);

    public static Matrix[] bmrbSd = new Matrix[] { bmrbSdAla, bmrbSdArg, bmrbSdAsp, bmrbSdAsn, bmrbSdCys, bmrbSdGlu, bmrbSdGln, bmrbSdGly, bmrbSdHis, bmrbSdIle, bmrbSdLeu, bmrbSdLys, bmrbSdMet, bmrbSdPhe, bmrbSdPro, bmrbSdSer, bmrbSdThr, bmrbSdTrp, bmrbSdTyr, bmrbSdVal, bmrbSdUnk };


    //--------------------------------------refdb standard deviations-------------------------------------
    static private Matrix refdbSdAla = new Matrix(new double[] { 0.66, 0.49, Double.NaN, 1.99, 1.91, 1.78, 4.04 }, dimAla.length);
    static private Matrix refdbSdArg = new Matrix(new double[] { 0.64, 0.5, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.98, 2.29, 1.68, Double.NaN, Double.NaN, Double.NaN, 3.96, Double.NaN, Double.NaN, Double.NaN }, dimArg.length);
    static private Matrix refdbSdAsp = new Matrix(new double[] { 0.6, 0.34, Double.NaN, Double.NaN, 1.66, 2.01, 1.5, Double.NaN, 4.07 }, dimAsp.length);
    static private Matrix refdbSdAsn = new Matrix(new double[] { 0.71, 0.42, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.78, 1.82, 1.66, Double.NaN, 4.46, Double.NaN }, dimAsn.length);
    static private Matrix refdbSdCys = new Matrix(new double[] { 0.73, 0.64, Double.NaN, Double.NaN, Double.NaN, 2.01, 3.35, 6.86, 4.33 }, dimCys.length); 
    static private Matrix refdbSdGlu = new Matrix(new double[] { 0.64, 0.45, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.87, 2.09, 1.74, Double.NaN, Double.NaN, 3.67 }, dimGlu.length);
    static private Matrix refdbSdGln = new Matrix(new double[] { 0.62, 0.48, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.87, 2.05, 1.8, Double.NaN, Double.NaN, 3.73, Double.NaN }, dimGln.length);
    static private Matrix refdbSdGly = new Matrix(new double[] { 0.76, 0.41, 0.41, 1.63, 1.18, Double.NaN }, dimGly.length);
    static private Matrix refdbSdHis = new Matrix(new double[] { 0.73, 0.52, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.94, 2.44, 2.23, Double.NaN, Double.NaN, Double.NaN, 4.09, Double.NaN, Double.NaN }, dimHis.length);
    static private Matrix refdbSdIle = new Matrix(new double[] { 0.75, 0.6, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.9, 2.65, 1.93, Double.NaN, Double.NaN, Double.NaN, 4.46 }, dimIle.length);
    static private Matrix refdbSdLeu = new Matrix(new double[] { 0.7, 0.52, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.91, 2.06, 1.8, Double.NaN, Double.NaN, Double.NaN, 4.13 }, dimLeu.length);
    static private Matrix refdbSdLys = new Matrix(new double[] { 0.68, 0.49, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.89, 2.11, 1.72, Double.NaN, Double.NaN, Double.NaN, 3.85, Double.NaN }, dimLys.length);
    static private Matrix refdbSdMet = new Matrix(new double[] { 0.65, 0.53, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 2, 2.2, 2.28, Double.NaN, Double.NaN, 3.66 }, dimMet.length);
    static private Matrix refdbSdPhe = new Matrix(new double[] { 0.77, 0.61, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.99, 2.57, 2.09, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 4.23 }, dimPhe.length);
    static private Matrix refdbSdPro = new Matrix(new double[] { 0.39, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.53, 1.46, 1.02, Double.NaN, Double.NaN, Double.NaN }, dimPro.length);
    static private Matrix refdbSdSer = new Matrix(new double[] { 0.65, 0.45, Double.NaN, Double.NaN, Double.NaN, 1.66, 2.01, 1.5, 3.81 }, dimSer.length);
    static private Matrix refdbSdThr = new Matrix(new double[] { 0.65, 0.51, Double.NaN, Double.NaN, Double.NaN, 1.65, 2.65, 1.54, Double.NaN, 4.94 }, dimThr.length);
    static private Matrix refdbSdTrp = new Matrix(new double[] { 0.86, 0.58, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.87, 2.34, 1.88, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 4.65, Double.NaN }, dimTrp.length);
    static private Matrix refdbSdTyr = new Matrix(new double[] { 0.79, 0.63, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 1.89, 2.52, 2.02, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, Double.NaN, 4.55 }, dimTyr.length);
    static private Matrix refdbSdVal = new Matrix(new double[] { 0.72, 0.61, Double.NaN, Double.NaN, Double.NaN, 1.87, 2.9, 1.68, Double.NaN, Double.NaN, 4.85 }, dimVal.length);
    static private Matrix refdbSdUnk = new Matrix(new double[] { 22.5, 22.5, 200, 200, 200, 100 }, dimUnk.length);

    public static Matrix[] refdbSd = new Matrix[] { refdbSdAla, refdbSdArg, refdbSdAsp, refdbSdAsn, refdbSdCys, refdbSdGlu, refdbSdGln, refdbSdGly, refdbSdHis, refdbSdIle, refdbSdLeu, refdbSdLys, refdbSdMet, refdbSdPhe, refdbSdPro, refdbSdSer, refdbSdThr, refdbSdTrp, refdbSdTyr, refdbSdVal, refdbSdUnk };


    //-----------------------------------------------------------------------------------------------
    //-------------------------------------------METHODS---------------------------------------------
    //-----------------------------------------------------------------------------------------------
    public static String getShortName(String aa) {
        int aaIndex = computeAaIndex(aa);
        return aaNames1[aaIndex];
    }

    public static String getLongName(String aa) {
        int aaIndex = computeAaIndex(aa);
        return aaNames3[aaIndex];
    }

    public static String[] getDimensions(String aa) {
        int aaIndex = computeAaIndex(aa);
        return dim[aaIndex];
    }

    public static Matrix[] getMeanAndVar(String aaToSelect, String[] dimNamesToSelect, String priorType) {

        int aaIndex = computeAaIndex(aaToSelect);
        BitSet isToSelect = dimToSelect(dim[aaIndex], dimNamesToSelect);

        // mean
        Matrix meanToReturn = null;
        if (priorType.equalsIgnoreCase("malliavin"))
            meanToReturn = malMean[aaIndex].copy();
        if (priorType.equalsIgnoreCase("bmrb"))
            meanToReturn = bmrbMean[aaIndex].copy();
        if (priorType.equalsIgnoreCase("refdb"))
            meanToReturn = refdbMean[aaIndex].copy();
        meanToReturn = Util.subset(meanToReturn, isToSelect, null);

        // var
        Matrix varToReturn = null;
        if (priorType.equalsIgnoreCase("malliavin"))
            varToReturn = malVar[aaIndex].copy();
        else {
            Matrix sdToReturn = null;
            if (priorType.equalsIgnoreCase("bmrb")) 
                sdToReturn = bmrbSd[aaIndex].copy();
            if (priorType.equalsIgnoreCase("refdb")) 
                sdToReturn = refdbSd[aaIndex].copy();

            varToReturn = new Matrix(sdToReturn.getRowDimension(), sdToReturn.getRowDimension());
            for (int i = 0; i < sdToReturn.getRowDimension(); i++)
                varToReturn.set(i, i, sdToReturn.get(i, 0) * sdToReturn.get(i, 0));
        }   

        varToReturn = Util.subset(varToReturn, isToSelect, isToSelect);
        return new Matrix[] { meanToReturn, varToReturn };
    }
    
	
    private static int computeAaIndex(String aa) {
        int index = -1;
        if (aa.length() == 1) {
            for (index = 0; index < aaNames1.length; index++)
                if (aaNames1[index].equals(aa))
                    break;
        } else if (aa.length() == 3) {
            for (index = 0; index < aaNames1.length; index++)
                if (aaNames3[index].equals(aa))
                    break;
        }
        return index;
    }

    public static boolean hasDimension(String aa, String myDim) {
        int aaIndex = computeAaIndex(aa);
        for (int i = 0; i < dim[aaIndex].length; i++)
            if (dim[aaIndex][i].equals(myDim))
                return true;
        return false;
    }
    
    private static BitSet dimToSelect(String[] origDim, String[] dimToSelect) {

        BitSet isToSelect = new BitSet(0, origDim.length);

        for (int i = 0; i < dimToSelect.length; i++) {
            for (int j = 0; j < origDim.length; j++) {
                if (dimToSelect[i].equalsIgnoreCase(origDim[j])) {
                    isToSelect.set(j);
                    break;
                }
            }
        }
        return isToSelect;
    }
	
	//-------


    public static void main(String[] args) {
        
        // means
        String s;
        s = "CA:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "CA")) {
               double dif = Util.subset(refdbMean[i], dimToSelect(dim[i], new String[] { "CA"}), null).get(0, 0) -
                Util.subset(bmrbMean[i], dimToSelect(dim[i], new String[] { "CA"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);

        s = "CB:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "CB")) {
               double dif = Util.subset(refdbMean[i], dimToSelect(dim[i], new String[] { "CB"}), null).get(0, 0) -
                Util.subset(bmrbMean[i], dimToSelect(dim[i], new String[] { "CB"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);

        s = "C:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "C")) {
               double dif = Util.subset(refdbMean[i], dimToSelect(dim[i], new String[] { "C"}), null).get(0, 0) -
                Util.subset(bmrbMean[i], dimToSelect(dim[i], new String[] { "C"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);

        s = "HA:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "HA")) {
               double dif = Util.subset(refdbMean[i], dimToSelect(dim[i], new String[] { "HA"}), null).get(0, 0) -
                Util.subset(bmrbMean[i], dimToSelect(dim[i], new String[] { "HA"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);

        s = "HA2:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "HA2")) {
               double dif = Util.subset(refdbMean[i], dimToSelect(dim[i], new String[] { "HA2"}), null).get(0, 0) -
                Util.subset(bmrbMean[i], dimToSelect(dim[i], new String[] { "HA2"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);


        // variances
        s = "sdCA:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "CA")) {
               double dif = Util.subset(refdbSd[i], dimToSelect(dim[i], new String[] { "CA"}), null).get(0, 0) -
                Util.subset(bmrbSd[i], dimToSelect(dim[i], new String[] { "CA"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);

        s = "sdCB:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "CB")) {
               double dif = Util.subset(refdbSd[i], dimToSelect(dim[i], new String[] { "CB"}), null).get(0, 0) -
                Util.subset(bmrbSd[i], dimToSelect(dim[i], new String[] { "CB"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);

        s = "sdC:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "C")) {
               double dif = Util.subset(refdbSd[i], dimToSelect(dim[i], new String[] { "C"}), null).get(0, 0) -
                Util.subset(bmrbSd[i], dimToSelect(dim[i], new String[] { "C"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);

        s = "sdHA:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "HA")) {
               double dif = Util.subset(refdbSd[i], dimToSelect(dim[i], new String[] { "HA"}), null).get(0, 0) -
                Util.subset(bmrbSd[i], dimToSelect(dim[i], new String[] { "HA"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);

        s = "sdHA2:\n";
        for (int i = 0; i < dim.length; i++) {
            if (hasDimension(aaNames1[i], "HA2")) {
               double dif = Util.subset(refdbSd[i], dimToSelect(dim[i], new String[] { "HA2"}), null).get(0, 0) -
                Util.subset(bmrbSd[i], dimToSelect(dim[i], new String[] { "HA2"}), null).get(0, 0);
               s += aaNames3[i] + ": " + dif;
            }
            s += "\n";
        }
        Util.pln(s);


    }


}
