/*
 * Created on Dec 22, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package input;

import java.util.Random;

import util.Util;
import Jama.Matrix;
import Jama.SingularValueDecomposition;
import assign.Worker;

public class Residue {

    // --------FIELDS----------------
    String longName;
    String shortName;
    String[] dimNames = { "H", "HA", "HA2", "C", "CA", "CB", "N" };
    
    Matrix mean;
    Matrix var;
    double[] simChemicalShifts = null;

    // --------CONSTRUCTOR----------------
    public Residue(String aa) {

        if (aa.length() == 1) {
            shortName = aa;
            longName = Bmrb.getLongName(aa);
        }
        if (aa.length() == 3) {
            longName = aa;
            shortName = Bmrb.getShortName(aa);
        }

        for (int i = 0; i < dimNames.length; i++) {
            if (!Bmrb.hasDimension(aa, dimNames[i]))
                dimNames[i] = null;
        }
        dimNames = (String[]) Util.stripEmpties(dimNames);

        Matrix[] meanAndVar = Bmrb.getMeanAndVar(aa, dimNames, Worker.priorType);
        mean = meanAndVar[0];
        var = meanAndVar[1];
    }

    // --------METHODS----------------
    public boolean isProline() {
        return shortName.equals("P");
    }

    public boolean isGlycine() {
        return shortName.equals("G");
    }

    public void simulate() {

        Random random = new Random();

        SingularValueDecomposition svd = var.svd();
        Matrix S = svd.getS();
        for (int i = 0; i < S.getColumnDimension(); i++) {
            if (S.get(0, 0) == 0) {
                Util.pln("Singular prior variance for residue type " + shortName + ". Can not simulate missing resonances. The program will now stop.");
                System.exit(0);
            }
            S.set(i, i, Math.sqrt(S.get(i, i)));
        }
        Matrix simVar = svd.getU().times(S).times(svd.getV().transpose());

        Matrix x = new Matrix(var.getRowDimension(), 1);
        for (int i = 0; i < var.getRowDimension(); i++)
            x.set(i, 0, random.nextGaussian());
        simChemicalShifts = mean.plus(simVar.times(x)).getColumnPackedCopy();

    }

    // --------ACCESSORS----------------
    public String getShortName() {
        return shortName;
    }

    public String getLongName() {
        return longName;
    }

    public String[] getDimNames() {
        return dimNames;
    }

    public Matrix getMean() {
        return mean;
    }

    public Matrix getVar() {
        return var;
    }

    public double getSimChemicalShift(String resType) {
        for (int i = 0; i < dimNames.length; i++)
            if (dimNames[i].equals(resType))
                return simChemicalShifts[i];
        return Double.NaN;
    }

}
