package input;

import assign.Worker.Argument;

import java.io.Serializable;

public class SpinSystem implements Serializable {

	// --------FIELDS----------------
	private final int id, referenceId;
	private final double hw, nw, cs, cas, cbs, has, ha2s, cw, caw, cbw, haw, ha2w;
	private final double hwv, nwv, csv, casv, cbsv, hasv, ha2sv, cwv, cawv, cbwv, hawv, ha2wv;

	private static boolean useH;
	private static boolean useN;
	private static boolean useC;
	private static boolean useCA;
	private static boolean useCB;
	private static boolean useHA;

	// --------CONSTRUCTORS----------------
	// empty spin system
	public SpinSystem(int id) {
		//id, HNw, N15w, COs, CAs, CBs, HAs, HA2s, COw, CAw, CBw, HAw, HA2w
		this.id = id;
		referenceId = -1;
		hw = Double.NaN;
		nw = Double.NaN;
		cs = Double.NaN;
		cas = Double.NaN;
		cbs = Double.NaN;
		has = Double.NaN;
		ha2s = Double.NaN;
		cw = Double.NaN;
		caw = Double.NaN;
		cbw = Double.NaN;
		haw = Double.NaN;
		ha2w = Double.NaN;
		hwv = Double.NaN;
		nwv = Double.NaN;
		csv = Double.NaN;
		casv = Double.NaN;
		cbsv = Double.NaN;
		hasv = Double.NaN;
		ha2sv = Double.NaN;
		cwv = Double.NaN;
		cawv = Double.NaN;
		cbwv = Double.NaN;
		hawv = Double.NaN;
		ha2wv = Double.NaN;
	}

	// observed spin system
	public SpinSystem(
		int id,
		int referenceId,
		double hw,
		double nw,
		double cs,
		double cas,
		double cbs,
		double has,
		double ha2s,
		double cw,
		double caw,
		double cbw,
		double haw,
		double ha2w,
		double hwv,
		double nwv,
		double csv,
		double casv,
		double cbsv,
		double hasv,
		double ha2sv,
		double cwv,
		double cawv,
		double cbwv,
		double hawv,
		double ha2wv) {
		//id, HNw, N15w, COs, CAs, CBs, HAs, HA2s, COw, CAw, CBw, HAw, HA2w
		this.id =  id;
		this.referenceId =  referenceId;
		this.hw = useH ? hw : Double.NaN;
		this.nw = useN ? nw : Double.NaN;
		this.cs = useC ? cs : Double.NaN;
		this.cas = useCA ? cas : Double.NaN;
		this.cbs = useCB ? cbs : Double.NaN;
		this.has = useHA ? has : Double.NaN;
		this.ha2s = useHA ? ha2s : Double.NaN;
		this.cw = useC ? cw : Double.NaN;
		this.caw = useCA ? caw : Double.NaN;
		this.cbw = useCB ? cbw : Double.NaN;
		this.haw = useHA ? haw : Double.NaN;
		this.ha2w = useHA ? ha2w : Double.NaN;
		this.hwv = useH ? hwv : Double.NaN;
		this.nwv = useN ? nwv : Double.NaN;
		this.csv = useC ? csv : Double.NaN;
		this.casv = useCA ? casv : Double.NaN;
		this.cbsv = useCB ? cbsv : Double.NaN;
		this.hasv = useHA ? hasv : Double.NaN;
		this.ha2sv = useHA ? ha2sv : Double.NaN;
		this.cwv = useC ? cwv : Double.NaN;
		this.cawv = useCA ? cawv : Double.NaN;
		this.cbwv = useCB ? cbwv : Double.NaN;
		this.hawv = useHA ? hawv : Double.NaN;
		this.ha2wv = useHA ? ha2wv : Double.NaN;
	}
	
	// set the flags that specify what information about new spin systems to use
	public static void setFlags(Argument arg) {
		useH = arg.useh;
		useN = arg.usen;
		useC = arg.usec;
		useCA = arg.useca;
		useCB = arg.usecb;
		useHA = arg.useha;
	}

	// --------METHODS----------------
	public int getDf() {
		int result = 0;
		result += (Double.isNaN(hw)) ? 0 : 1;
		result += (Double.isNaN(nw)) ? 0 : 1;

		result += (Double.isNaN(cs)) ? 0 : 1;
		result += (Double.isNaN(cw)) ? 0 : 1;

		result += (Double.isNaN(cas)) ? 0 : 1;
		result += (Double.isNaN(caw)) ? 0 : 1;

		result += (Double.isNaN(cbs)) ? 0 : 1;
		result += (Double.isNaN(cbw)) ? 0 : 1;

		result += (Double.isNaN(has)) ? 0 : 1;
		result += (Double.isNaN(haw)) ? 0 : 1;
		result += (Double.isNaN(ha2s)) ? 0 : 1;
		result += (Double.isNaN(ha2w)) ? 0 : 1;

		return result;
	}

	public int getChemicalShiftCount() {
		int result = 0;
		result += (Double.isNaN(cs)) ? 0 : 1;
		result += (Double.isNaN(cw)) ? 0 : 1;

		result += (Double.isNaN(cas)) ? 0 : 1;
		result += (Double.isNaN(caw)) ? 0 : 1;

		result += (Double.isNaN(cbs)) ? 0 : 1;
		result += (Double.isNaN(cbw)) ? 0 : 1;

		result += (Double.isNaN(has)) ? 0 : 1;
		result += (Double.isNaN(haw)) ? 0 : 1;
		result += (Double.isNaN(ha2s)) ? 0 : 1;
		result += (Double.isNaN(ha2w)) ? 0 : 1;

		return result;
	}

	public boolean isEmpty() {		
		return referenceId == -1;
	}

	public boolean canFollowGly() {
		return Double.isNaN(cbs);
	}

	public boolean canBeGly() {
		return Double.isNaN(cbw);
	}

	public boolean canFollowNonGly() {
		return Double.isNaN(ha2s);
	}

	public boolean canBeNonGly() {
		return Double.isNaN(ha2w);
	}

	public SpinSystem copy() {
		return new SpinSystem(
			id,
			referenceId,
			hw,
			nw,
			cs,
			cas,
			cbs,
			has,
			ha2s,
			cw,
			caw,
			cbw,
			haw,
			ha2w,
			hwv,
			nwv,
			csv,
			casv,
			cbsv,
			hasv,
			ha2sv,
			cwv,
			cawv,
			cbwv,
			hawv,
			ha2wv);
	}

	public String toString() {
		if (isEmpty())
			return "-1";
		return  "" + referenceId;
	}

	//-----------------------------------------------------------------------------------
	//---------------------------------OBJECT IDENTITY-----------------------------------
	//-----------------------------------------------------------------------------------
	
	// The id field completely determines the object's identity.
	
	public boolean equals(Object o) {
		SpinSystem s = (SpinSystem) o;
		return (id == s.id);
	}
	
	public int hashCode() {
		return id;
	}
	
	// --------ACCESSORS----------------
	public int getId() {
		return id;
	}

	public int getReferenceId() {
		return referenceId;
	}

	public double getHw() {
		return hw;
	}

	public double getNw() {
		return nw;
	}

	public double getCs() {
		return cs;
	}

	public double getCAs() {
		return cas;
	}

	public double getCBs() {
		return cbs;
	}

	public double getHAs() {
		return has;
	}

	public double getHA2s() {
		return ha2s;
	}

	public double getCw() {
		return cw;
	}

	public double getCAw() {
		return caw;
	}

	public double getCBw() {
		return cbw;
	}

	public double getHAw() {
		return haw;
	}

	public double getHA2w() {
		return ha2w;
	}

	public double getHwv() {
		return hwv;
	}

	public double getNwv() {
		return nwv;
	}

	public double getCsv() {
		return csv;
	}

	public double getCAsv() {
		return casv;
	}

	public double getCBsv() {
		return cbsv;
	}

	public double getHAsv() {
		return hasv;
	}

	public double getHA2sv() {
		return ha2sv;
	}

	public double getCwv() {
		return cwv;
	}

	public double getCAwv() {
		return cawv;
	}

	public double getCBwv() {
		return cbwv;
	}

	public double getHAwv() {
		return hawv;
	}

	public double getHA2wv() {
		return ha2wv;
	}
}
