package output;

import input.Protein;
import util.Util;
import assign.Strand;
import assign.Worker;

public class ReferenceMapping {

    private Strand[] strands;
    private Strand referenceStrand;

    //context
    private static Protein protein = Worker.protein;

    //-----------------------------------------------------------------------------------
    //--------------------------------CONSTRUCTORS---------------------------------------
    //-----------------------------------------------------------------------------------
    //---------------initialize form a specific sequence of spin systems-----------------
    public ReferenceMapping(int[] inputIds) {

        // strands of length 1 at each position
        strands = new Strand[inputIds.length];
        for (int pos = 0; pos < inputIds.length; pos++) {
            strands[pos] = new Strand(protein.getSpinSystemByReferenceId(inputIds[pos]), pos);
        }

        // merging strands into one
        Strand[] merger = (Strand[]) Util.copy(strands);
        for (int pos = 0; pos < protein.getLength() - 1; pos++) {
            merger[pos + 1] = new Strand(merger[pos], merger[pos + 1]);
            merger[pos] = null;
        }
        merger = (Strand[]) Util.stripEmpties(merger);
        referenceStrand = merger[0];

    }

    //-----------------------------------------------------------------------------------
    //-------------------------------------METHODS---------------------------------------
    //-----------------------------------------------------------------------------------

    public double computePredMeanCA(int pos) {
        double result = 0;
        int count = 0;

        result += Double.isNaN(referenceStrand.getSpinSystems()[pos].getCAw()) ? 0 : referenceStrand.getSpinSystems()[pos].getCAw();
        if (pos != protein.getLastPos())
            result += Double.isNaN(referenceStrand.getSpinSystems()[pos + 1].getCAs()) ? 0 : referenceStrand.getSpinSystems()[pos + 1].getCAs();

        count += Double.isNaN(referenceStrand.getSpinSystems()[pos].getCAw()) ? 0 : 1;
        if (pos != protein.getLastPos())
            count += Double.isNaN(referenceStrand.getSpinSystems()[pos + 1].getCAs()) ? 0 : 1;

        result = (count == 0) ? Double.NaN : (result / count);
        return result;

    }

    public String toString() {

        String s = "\n\n\nREFERENCE MAPPING:\n";

        s += "Score joint = " + Util.round(referenceStrand.getScoreJoint(), 4) + " df = " + referenceStrand.getDfJoint();
        s += "\nScore match = " + Util.round(referenceStrand.getScoreMatch(), 4) + " df = " + referenceStrand.getDfMatch();
        s += "\nScore align = "
            + Util.round(referenceStrand.getScoreAlign(), 4)
            + " df = "
            + referenceStrand.getDfAlign()
            + "\nInconsistent pairs:\n";

        int inconsistentPairsCount = 0;
        for (int i = 0; i < protein.getLength() - 1; i++) {
            if (!Strand.isConsistent(strands[i], strands[i + 1])) {
                s += "[" + Util.pad(i + "", 3) + "," + Util.pad(i + 1 + "", 3) + "] - ";
                if (!Worker.scoreHandler.isValidMatch(strands[i].getRight(), strands[i + 1].getLeft()))
                    s += " match";
                if (!Worker.scoreHandler.isValidAlign(i, strands[i].getRight(), strands[i + 1].getLeft()))
                    s += " align";
                if (!Worker.scoreHandler.isValidJoint(i, strands[i].getRight(), strands[i + 1].getLeft()))
                    s += " joint";
                s += "\n";
                inconsistentPairsCount++;
            }
        }
        if (inconsistentPairsCount == 0)
            s += "None";

        return s;
    }

}
