package parallel;

import util.Util;

import EDU.oswego.cs.dl.util.concurrent.FJTaskRunner;
import EDU.oswego.cs.dl.util.concurrent.FJTaskRunnerGroup;

/**
 * A specialized variant of FJTaskRunner designed to be used by MovableTaskRunnerGroup.
 * 
 * @author kulinipm
 */
public class MovableTaskRunner extends FJTaskRunner {

	public MovableTaskRunner(FJTaskRunnerGroup group) {
		super(group);
	}
	
	// Wrapper to notify the group if the thread must terminate abnormally.
	public void run() {
		try {
			super.run();
		}
		catch (TerminateException e) {
			if (e.isDeliberate())
				Util.debugln("MovableTaskRunner told to terminate deliberately.");
			else {
				Util.debugln("MovableTaskRunner forced to terminate; offloading all its pending tasks.");
				offload();
				MovableTaskRunnerGroup group = (MovableTaskRunnerGroup) getGroup();
				group.threadDied();
			}
		}
		finally {
			Util.debugln("MovableTaskRunner terminating.");
		}
	}
	
	// FJTaskRunner.take() is final, so we need to declare a different method to do this
	public MovableTask takeProxy() {
		return (MovableTask) take();
	}
	
	// FJTaskRunner.put() is final, so we need to declare a different method to do this
	public void putProxy(MovableTask task) {
		put(task);
	}
	
	// Offload all pending tasks back onto the client.
	private void offload() {
		MovableTask oldestTask = takeProxy();
		while (oldestTask != null) {
			oldestTask.offload();
			oldestTask = takeProxy();
		}
	}
	
	public static class TerminateException extends RuntimeException {
		private boolean deliberate;
		
		public TerminateException(boolean offloadTasks) {
			this.deliberate = offloadTasks;
		}
		
		public boolean isDeliberate() {
			return deliberate;
		}
	}
}
