package parallel;

import assign.SearchByFixedPosTask;
import assign.Solution;
import assign.Worker;
import assign.Worker.Argument;

/**
 * Parallelizes computation by splitting up the work into small tasks and
 * using a thread pool to execute them.  A single Worker object is shared
 * between all the threads.
 * 
 * @author kulinipm
 */
public class ThreadedParallelizer extends Parallelizer {
	
	private int numThreads;
	
	//-----------------------------------------------------------------------------------
	//-----------------------------CONSTRUCTORS------------------------------------------
	//-----------------------------------------------------------------------------------
	
	public ThreadedParallelizer(Argument arg) {
		
		//-------------------------initialize working environment-----------------------
		Worker.initialize(arg);
		numThreads = arg.threads;
	}
	
	public void start() {
		
		//-----------------------info on reference solution if any----------------------
		Worker.computeReferenceSolution();
		
		//----------------------------initialize search---------------------------------
		Solution.initialize();
		
		//----------------------------search of solutions-------------------------------
		MovableTaskRunnerGroup group = new MovableTaskRunnerGroup(numThreads);
		enqueueTask(new SearchByFixedPosTask());
		try {
			for (MovableTask task = dequeueTask(); task != null; task = dequeueTask()) {
				group.invoke(task);
			}
		} catch(InterruptedException ex) {
			// breaks out of loop
		}
		group.interruptAll();
		group.stats();
	}
}
