/*
 * Created on Dec 22, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package input;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.Arrays;
import java.util.Comparator;
import java.util.StringTokenizer;

import util.BitSet;
import util.Util;
import assign.Worker;
import assign.Worker.Argument;

public class Protein {

    // protein
    private String comment;
    private int length;
    private Residue[] sequence;
    private BitSet isAssignablePos;
    private BitSet isAssignedInReference;
    private int lastPos;
    private SpinSystem[] spinSystems;
    private SpinSystem[] rejectedSpinSystems;

    //-----------------------------------------------------------------------
    //-----------------------------CONSTRUCTOR-------------------------------
    //-----------------------------------------------------------------------
    //---------------constructor from both real and simulated data-----------
    // takes data in MBA format brom a file and constructs a protein
    public Protein(String file, Argument arg) {

        BufferedReader inputStream = null;
        int j = 0;
        int k = 0;

        try {
            inputStream = new BufferedReader(new FileReader(file));

            // comment
            comment = inputStream.readLine();

            // length
            String string = inputStream.readLine();
            length = string.length();
            lastPos = length - 1;

            // sequence
            sequence = new Residue[length];
            for (int i = 0; i < length; i++)
                sequence[i] = new Residue(string.substring(i, i + 1));

            // set to true if assignable
            isAssignablePos = new BitSet(0, length);
            for (int i = 1; i < length; i++) {
                if (!this.sequence[i].isProline()) {
                    isAssignablePos.set(i);
                }
            }

            // is assigned in reference solution
            isAssignedInReference = isAssignablePos.copy();
            StringTokenizer stringTokenizer = new StringTokenizer(inputStream.readLine(), ",");
            while (stringTokenizer.hasMoreTokens()) {
                int pos = Integer.parseInt(stringTokenizer.nextToken());
                if (pos == -1)
                    break;
                isAssignedInReference.unset(pos);
            }

            // spin systems
            spinSystems = new SpinSystem[length * 2];
            rejectedSpinSystems = new SpinSystem[length];

            String line = inputStream.readLine();
            while (line != null) {
                stringTokenizer = new StringTokenizer(line, ",");

                spinSystems[j] =
                    new SpinSystem(
                        j,
                        Integer.parseInt(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        Double.parseDouble(stringTokenizer.nextToken()),
                        arg.tauH,
                        arg.tauN,
                        arg.tauC,
                        arg.tauCA,
                        arg.tauCB,
                        arg.tauHA,
                        arg.tauHA,
                        arg.tauC,
                        arg.tauCA,
                        arg.tauCB,
                        arg.tauHA,
                        arg.tauHA);

                if (spinSystems[j].getChemicalShiftCount() >= arg.minChemicalShiftCount)
                    j++;
                else {
                    rejectedSpinSystems[k] = spinSystems[j];
                    k++;
                }

                line = inputStream.readLine();
            }

        } catch (FileNotFoundException e) {
            Util.pln("File " + file + " with input data not found. The program will now stop");
            System.exit(0);
        } catch (IOException e) {
            Util.pln("Error reading from file " + file + ". The program will now stop");
            System.exit(0);
        }

        spinSystems[j] = new SpinSystem(j);
        spinSystems = (SpinSystem[]) Util.truncate(spinSystems, j + 1);
        rejectedSpinSystems = (SpinSystem[]) Util.truncate(rejectedSpinSystems, k);

    }

    //-----------------------------------------------------------------------
    //------------------------------METHODS----------------------------------
    //-----------------------------------------------------------------------
    public int computeMaxDf() {
        SpinSystem[] copyOfSpinSystems = (SpinSystem[]) Util.copy(spinSystems);

        // sort spin systems
        Arrays.sort(copyOfSpinSystems, new Comparator() {
            public int compare(Object a, Object b) {
                return - ((SpinSystem) a).getDf() + ((SpinSystem) b).getDf();
            }
        });

        // count number of assignable positions
        int assignablePositions = 0;
        for (int i = 1; i < length; i++)
            if (!sequence[i].isProline())
                assignablePositions++;

        // compute maxDf
        int maxDF = 0;
        for (int i = 0; i < assignablePositions && i < spinSystems.length; i++)
            maxDF += copyOfSpinSystems[i].getDf();
        return maxDF;
    }

    public String toStringStats() {

        // used data set stats
        int countExtraSSused = Math.max(spinSystems.length - 1 + Worker.maxMissings - isAssignablePos.cardinality(), 0);
        int countMissSSused = Worker.maxMissings;

        int countMinCSused = Integer.MAX_VALUE;
        int countMaxCSused = Integer.MIN_VALUE;
        int countPresentResInSSused = 0;
        for (int i = 0; i < spinSystems.length - 1; i++) {
            countMinCSused = Math.min(countMinCSused, spinSystems[i].getChemicalShiftCount());
            countMaxCSused = Math.max(countMaxCSused, spinSystems[i].getChemicalShiftCount());
            countPresentResInSSused += spinSystems[i].getChemicalShiftCount();
        }
        double propMissResInSSused = (spinSystems.length * 8 - countPresentResInSSused) * 100 / (spinSystems.length * 8);

        // original data set stats
        int countMissSS = isAssignablePos.cardinality() - isAssignedInReference.cardinality();
        int countExtraSS = spinSystems.length - 1 + rejectedSpinSystems.length - isAssignedInReference.cardinality();

        int countMinCS = countMinCSused;
        int countMaxCS = countMaxCSused;
        int countPresentResInSS = countPresentResInSSused;
        for (int i = 0; i < rejectedSpinSystems.length; i++) {
            countMinCS = Math.min(countMinCS, rejectedSpinSystems[i].getChemicalShiftCount());
            countMaxCS = Math.max(countMaxCS, rejectedSpinSystems[i].getChemicalShiftCount());
            countPresentResInSS += rejectedSpinSystems[i].getChemicalShiftCount();
        }
        double propMissResInSS =
            (spinSystems.length * 8 + rejectedSpinSystems.length * 8 - countPresentResInSS)
                * 100
                / (spinSystems.length * 8 + rejectedSpinSystems.length * 8);

        String s =
        "\n\n\nCOMMENT:\n"
                + comment 
                + "\n\n\nDESCRIPTION OF THE ORIGINAL DATA SET:"
                + "\nMissing spin systems in reference solution: "
                + countMissSS
                + "\nExtra spin systems in reference solution: "
                + countExtraSS
                + "\nMin chemical shifts per spin system in the original data set: "
                + countMinCS
                + "\nMax chemical shifts per spin system in the original data set: "
                + countMaxCS
                + "\nProp missing resonances in all observed spin systems: "
                + Util.round(propMissResInSS, 2)
                + "%";

        s += "\n\n\nDESCRIPTION OF THE SPIN SYSTEMS USED"
            + "\nMissing spin systems used: "
            + countMissSSused
            + "\nExtra spin systems used: "
            + countExtraSSused
            + "\nMin chemical shifts per spin system used: "
            + countMinCSused
            + "\nMax chemical shifts per spin system used: "
            + countMaxCSused
            + "\nProp missing resonances in all spin systems used: "
            + Util.round(propMissResInSSused, 2)
            + "%";

        return s;
    }

    //-----------------------------------------------------------------------
    //------------------------------ACCESSORS----------------------------------
    //-----------------------------------------------------------------------
    public String getComment() {
        return comment;
    }

    public int getLength() {
        return length;
    }

    public int getLastPos() {
        return lastPos;
    }

    public SpinSystem[] getSpinSystems() {
        return spinSystems;
    }

    public BitSet getAssignablePositions() {
        return isAssignablePos;
    }

    public BitSet getAssignedInReference() {
        return isAssignedInReference;
    }

    public Residue getResidueAt(int i) {
        return sequence[i];
    }

    public SpinSystem getEmptySpinSystem() {
        return spinSystems[spinSystems.length - 1];
    }

    public SpinSystem getSpinSystemByReferenceId(int id) {
        for (int i = 0; i < spinSystems.length; i++)
            if (spinSystems[i].getReferenceId() == id)
                return spinSystems[i];

        return getEmptySpinSystem();
    }

    public int[] getReferenceSequenceById() {
        int[] id = new int[length];
        for (int pos = 0; pos < length; pos++) {
            if (isAssignedInReference.test(pos) == true)
                id[pos] = pos;
            else
                id[pos] = -1;
        }
        return id;
    }
}
